#ifdef __linux__
#define CONFIG_SECTION SECTION(".dte.config") ALIGNED(8)
#else
#define CONFIG_SECTION
#endif

IGNORE_WARNING("-Woverlength-strings")

static CONFIG_SECTION const char builtin_rc[] =
"include -b binding/default\n"
"include -b color/default\n"
"include -b compiler/gcc\n"
"include -b compiler/go\n"
"\n"
"alias help 'run man dterc'\n"
"alias make 'compile gcc make'\n"
"alias man 'run man'\n"
"alias read 'pipe-from cat'\n"
"alias reverse-lines 'filter tac'\n"
"alias sort-lines 'filter sh -c \042LC_COLLATE=C sort\042'\n"
"alias split-words 'replace -g \042[ \134t]+\042 \042\134n\042'\n"
"alias trim-lines 'replace \042[ \134t]+$\042 \042\042'\n"
"alias color hi\n"
"alias exit quit\n"
"\n"
"errorfmt basic\n"
"errorfmt basic '^([^:]+):([0-9]+):([0-9]+): *(.*)$' file line column message\n"
"errorfmt basic '^([^:]+):([0-9]+): *(.*)$' file line message\n"
"alias git-grep 'compile -1s basic git grep -n'\n"
"\n"
"# Remove possible 'F' from $LESS so that less will always wait\n"
"# for keypress and \042run\042 can be used without \042-p\042.\n"
"# ('R' = allow ANSI colors, 'S' = chop long lines)\n"
"setenv LESS RS\n"
"\n"
"ft -f dte '/(\134.|dot_)?dte/(config/)?(rc|((syntax|color|binding|compiler)/.*))$'\n"
"ft -f mail '/tmpmsg-.*\134.txt$|pico\134.[0-9]+|/tmp/mutt(ng)?-'\n"
"\n"
"# Don't remember cursor position for git temporary files\n"
"option gitcommit,gitrebase file-history false\n"
"option -r '/\134.git/.*\134.diff$' file-history false\n"
"\n"
"# Try to detect indent settings based on existing file contents\n"
"option c,css,d,java,javascript,lua,nginx,php,sh,vala detect-indent 2,4,8\n"
"\n"
"# Scan for braces to determine next auto-ident size\n"
"option c,css,d,go,java,javascript,lua,nginx,php,sh,vala brace-indent true\n"
"\n"
"# Override indent options for Makefiles, since they almost always require tabs\n"
"option make indent-width 8 expand-tab false emulate-tab false\n"
"\n"
"# Use space indents in YAML files, since the language spec doesn't allow tabs\n"
"option yaml \134\n"
"    expand-tab true \134\n"
"    emulate-tab true \134\n"
"    ws-error tab-indent,tab-after-indent,trailing,special\n"
"\n"
"# Patterns used to detect indent size when \042auto-indent\042 option is enabled\n"
"option c,java indent-regex '^[ \134t]*((case|do|else|for|if|while)[ (]|default:)'\n"
"option lua indent-regex '(then|do|repeat|else) *$|function *[A-Za-z0-9_.:]* *\134([A-Za-z0-9_, ]*\134) *$'\n"
"option php indent-regex '^[ \134t]*(case|default|do|else|for|foreach|if|while)[ (]'\n"
"option python indent-regex ':[ \134t]*(#.*)?$'\n"
"option sh indent-regex '(^|;)[ \134t]*(do|else|then) *$'\n"
"\n"
"# Don't highlight whitespace errors in diff and mail files\n"
"option diff,mail ws-error 0\n"
"\n"
"# Aliases for renamed/removed commands (for backwards compatibility)\n"
"alias filter 'exec -s -i buffer -o buffer -e errmsg'\n"
"alias pipe-from 'exec -s -o buffer -e errmsg'\n"
"alias pipe-to 'exec -s -i buffer -e errmsg'\n"
"alias run 'exec'\n"
"alias eval 'exec -o eval'\n"
"alias exec-open 'exec -o open'\n"
"alias exec-tag 'exec -o tag'\n"
"alias exec-msg 'exec -o msg -i msg'\n"
"alias format-paragraph wrap-paragraph\n"
"alias pass-through pipe-from\n"
"alias git-open 'exec-open sh -c \042git ls-files $(git rev-parse --show-cdup) | fzf -m --reverse\042'\n"
"alias insert-builtin 'show include'\n"
;

static CONFIG_SECTION const char builtin_binding_default[] =
"bind left left\n"
"bind right right\n"
"bind up up\n"
"bind down down\n"
"bind home bol\n"
"bind end eol\n"
"bind pgup pgup\n"
"bind pgdown pgdown\n"
"bind delete delete\n"
"\n"
"bind C-left 'word-bwd -s'\n"
"bind C-right 'word-fwd -s'\n"
"bind C-up up\n"
"bind C-down down\n"
"bind M-left bol\n"
"bind M-right eol\n"
"bind M-up pgup\n"
"bind M-down pgdown\n"
"bind M-delete 'delete-word -s'\n"
"bind M-C-delete 'delete-line'\n"
"\n"
"bind S-left 'left -c'\n"
"bind S-right 'right -c'\n"
"bind S-up 'up -c'\n"
"bind S-down 'down -c'\n"
"bind S-home 'bol -c'\n"
"bind S-end 'eol -c'\n"
"bind S-pgup 'pgup -c'\n"
"bind S-pgdown 'pgdown -c'\n"
"\n"
"bind C-S-left 'word-bwd -cs'\n"
"bind C-S-right 'word-fwd -cs'\n"
"bind C-S-up 'up -l'\n"
"bind C-S-down 'down -l'\n"
"bind C-S-pgup 'pgup -l'\n"
"bind C-S-pgdown 'pgdown -l'\n"
"bind C-S-delete 'delete-eol'\n"
"\n"
"bind M-S-left 'bol -c'\n"
"bind M-S-right 'eol -c'\n"
"bind M-S-up 'pgup -c'\n"
"bind M-S-down 'pgdown -c'\n"
"bind M-S-delete 'delete-eol'\n"
"\n"
"bind C-M-S-left 'bol -c'\n"
"bind C-M-S-right 'eol -c'\n"
"bind C-M-S-up 'pgup -l'\n"
"bind C-M-S-down 'pgdown -l'\n"
"bind C-M-S-pgup 'pgup -l'\n"
"bind C-M-S-pgdown 'pgdown -l'\n"
"bind C-M-S-delete 'delete-eol'\n"
"\n"
"# Either Ctrl+H or Ctrl+? may be equivalent to Backspace, depending\n"
"# on the terminal, so they're both bound to \042erase\042 by default for\n"
"# portability. On some terminals one may be equivalent to Backspace\n"
"# and the other Ctrl+Backspace.\n"
"bind C-h erase\n"
"bind C-? erase\n"
"bind M-C-h 'erase-word -s'\n"
"bind M-C-? 'erase-word -s'\n"
"\n"
"bind C-c 'copy -k'\n"
"bind C-f search\n"
"bind C-g 'search -n'\n"
"# C-i == Tab\n"
"bind C-l 'command line\134 '\n"
"# C-m == Enter\n"
"bind C-n open\n"
"bind C-o 'command open\134 '\n"
"bind C-q 'quit -p'\n"
"bind C-r 'command replace\134 '\n"
"bind C-s 'save -p'\n"
"bind C-t open\n"
"bind C-v 'paste -a'\n"
"bind C-w 'close -pwq'\n"
"bind C-x cut\n"
"bind C-y redo\n"
"bind C-z undo\n"
"bind C-] tag\n"
"bind C-[ unselect\n"
"\n"
"bind M-b bof\n"
"bind M-c 'toggle -v case-sensitive-search'\n"
"bind M-e eof\n"
"bind M-f 'search -w'\n"
"bind M-S-f 'search -wr'\n"
"bind M-j wrap-paragraph\n"
"bind M-n 'msg -n'\n"
"bind M-p 'msg -p'\n"
"bind M-t 'insert -m \042\134t\042'\n"
"bind M-x command\n"
"bind M-z suspend\n"
"\n"
"bind M-1 'view 1'\n"
"bind M-2 'view 2'\n"
"bind M-3 'view 3'\n"
"bind M-4 'view 4'\n"
"bind M-5 'view 5'\n"
"bind M-6 'view 6'\n"
"bind M-7 'view 7'\n"
"bind M-8 'view 8'\n"
"bind M-9 'view 9'\n"
"bind M-0 'view last'\n"
"\n"
"bind M-, prev\n"
"bind M-. next\n"
"bind M-- 'shift -- -1'\n"
"bind M-= 'shift +1'\n"
"bind M-\134; command\n"
"bind M-/ search\n"
"\n"
"bind M-< wprev\n"
"bind M-> wnext\n"
"bind M-: command\n"
"bind M-? 'search -r'\n"
"bind M-! 'move-tab left'\n"
"bind M-@ 'move-tab right'\n"
"\n"
"bind M-S-, wprev\n"
"bind M-S-. wnext\n"
"bind M-S-\134; command\n"
"bind M-S-/ 'search -r'\n"
"bind M-S-1 'move-tab left'\n"
"bind M-S-2 'move-tab right'\n"
"\n"
"bind F1 'run man dterc'\n"
"bind F3 'search -n'\n"
"bind F4 'search -p'\n"
"bind F5 refresh\n"
"\n"
"# Most terminals don't support sending these modifier+key combinations\n"
"# as distinct sequences, so don't be surprised if they don't work.\n"
"bind C-tab next\n"
"bind C-S-tab prev\n"
"\n"
"# Command/search mode bindings:\n"
"bind -cs left left\n"
"bind -cs right right\n"
"bind -cs up history-prev\n"
"bind -cs down history-next\n"
"bind -cs home bol\n"
"bind -cs end eol\n"
"bind -cs delete delete\n"
"bind -cs C-left word-bwd\n"
"bind -cs C-right word-fwd\n"
"bind -cs M-left bol\n"
"bind -cs M-right eol\n"
"bind -cs C-delete delete-word\n"
"bind -cs M-delete delete-word\n"
"bind -cs C-M-h erase-word\n"
"bind -cs C-M-? erase-word\n"
"bind -cs C-a bol\n"
"bind -cs C-b left\n"
"bind -cs C-c cancel\n"
"bind -cs C-d delete\n"
"bind -cs C-e eol\n"
"bind -cs C-f right\n"
"bind -cs C-g cancel\n"
"bind -cs C-h erase\n"
"bind -cs C-k delete-eol\n"
"bind -cs C-u erase-bol\n"
"bind -cs C-w erase-word\n"
"bind -cs C-? erase\n"
"bind -cs C-[ cancel\n"
"bind -cs M-b word-bwd\n"
"bind -cs M-d delete-word\n"
"bind -cs M-f word-fwd\n"
"bind -cs enter accept\n"
"bind -c tab complete-next\n"
"bind -c S-tab complete-prev\n"
"bind -s M-enter 'accept -e'\n"
"bind -s M-c 'toggle case-sensitive-search'\n"
"bind -s M-r direction\n"
;

static CONFIG_SECTION const char builtin_compiler_gcc[] =
"errorfmt gcc\n"
"errorfmt -i gcc 'error: \134(Each undeclared identifier is reported only once'\n"
"errorfmt -i gcc 'error: for each function it appears in.\134)'\n"
"errorfmt -i gcc '^([^:]+):([0-9]+): (error|warning): \134(near '\n"
"errorfmt -i gcc '^([^:]+):([0-9]+):([0-9]+):$'\n"
"\n"
"errorfmt gcc '^([^:]+):([0-9]+):([0-9]+): (.*)' file line column message\n"
"errorfmt gcc '^([^:]+):([0-9]+): (.*)' file line message\n"
"errorfmt gcc '^.* at (.+):([0-9]+):$' file line\n"
"errorfmt gcc \042 *inlined from '.*' at (.*):([0-9]+):\042 file line\n"
"\n"
"# ASan stack trace (e.g. \042 #12 0x55af25320630 in func_name src/filename.c:1142\042)\n"
"errorfmt gcc '^ *(#[0-9]+ 0x[0-9A-Fa-f]+ in [[:alnum:]_]+) ([^:]+):([0-9]+)$' message file line\n"
"\n"
"errorfmt -i gcc '^In file included from (.+):([0-9]+)[,:]'\n"
"errorfmt -i gcc '^ +from (.+):([0-9]+)[,:]'\n"
"errorfmt -i gcc '^([^:]+): (In function .*:)$'\n"
"errorfmt -i gcc \042^In function '.*',$\042\n"
"errorfmt -i gcc '^([^:]+): At top level:$'\n"
"errorfmt -i gcc '^cc1: (all |some )?warnings being treated as errors$'\n"
"errorfmt -i gcc '^make: \134*\134*\134* \134[.*\134] Error [0-9]+$'\n"
"errorfmt -i gcc '^make: \134*\134*\134* Waiting for unfinished jobs'\n"
"errorfmt -i gcc '^make: \134*\134*\134* wait: No child processes.  Stop'\n"
"errorfmt -i gcc '^collect2: ld returned [0-9]+ exit status$'\n"
"errorfmt -i gcc '^[ \134t]'\n"
"errorfmt -i gcc '^[0-9]+ warnings? generated.$'\n"
;

static CONFIG_SECTION const char builtin_compiler_go[] =
"errorfmt go\n"
"errorfmt go '^(.+):([0-9]+):([0-9]+): (.*)' file line column message\n"
"errorfmt go '^(.+):([0-9]+): (.*)' file line message\n"
"errorfmt go -i '^#'\n"
;

static CONFIG_SECTION const char builtin_color_reset[] =
"# For terminals that support basic attributes but not colors (e.g. vt220):\n"
"hi default\n"
"hi nontext reverse\n"
"hi noline\n"
"hi wserror reverse\n"
"hi selection reverse\n"
"hi currentline keep keep keep\n"
"hi linenumber reverse\n"
"hi statusline reverse\n"
"hi commandline\n"
"hi errormsg bold\n"
"hi infomsg\n"
"hi tabbar reverse\n"
"hi activetab bold\n"
"hi inactivetab reverse\n"
"hi dialog reverse\n"
"\n"
"# For terminals that support at least 8 colors:\n"
"hi -c nontext blue keep\n"
"hi -c noline blue\n"
"hi -c wserror default yellow\n"
"hi -c selection keep gray keep\n"
"hi -c statusline black gray\n"
"hi -c errormsg bold red\n"
"hi -c infomsg bold blue\n"
"hi -c tabbar black gray\n"
"hi -c inactivetab black gray\n"
"hi -c dialog white red bold\n"
;

static CONFIG_SECTION const char builtin_color_default[] =
"# This is the color scheme that gets loaded by default when the editor\n"
"# starts. It mostly uses the basic color palette, in order to maximize\n"
"# compatibility and remain suitable for both light and dark terminals.\n"
"\n"
"hi\n"
"hi selection default blue\n"
"\n"
"hi text\n"
"hi code\n"
"hi ident\n"
"hi keyword bold\n"
"hi type green\n"
"hi comment cyan\n"
"hi numeric blue\n"
"hi string yellow\n"
"hi variable bold yellow\n"
"hi constant bold cyan\n"
"hi special magenta\n"
"hi char magenta\n"
"hi label bold red\n"
"hi notice bold red\n"
"hi error black yellow\n"
"hi -c comment 245\n"
"hi -c linenumber 250 237\n"
"\n"
"hi tex.macro bold yellow\n"
"hi ini.section bold\n"
"hi make.builtin bold magenta\n"
"hi make.special-target green\n"
"hi markdown.heading bold magenta\n"
"hi markdown.emphasis cyan\n"
"hi markdown.strong-emphasis bold cyan\n"
"hi markdown.code-block yellow\n"
"hi markdown.code-span yellow\n"
"hi markdown.block-quote green\n"
"hi markdown.reference bold blue\n"
"hi markdown.url blue\n"
"hi html.tag bold magenta\n"
"hi html.attr magenta\n"
"hi xml.tag bold magenta\n"
"hi xml.attr magenta\n"
"hi diff.header cyan\n"
"hi diff.chunk magenta\n"
"hi diff.added bold green\n"
"hi diff.removed bold red\n"
"hi zig.builtin cyan\n"
;

static CONFIG_SECTION const char builtin_color_darkgray[] =
"# Reset\n"
"hi\n"
"\n"
"hi default 250 235\n"
"hi nontext 5/3/0 keep\n"
"hi noline  234 234\n"
"hi wserror default 5/5/3\n"
"hi selection keep 238 keep\n"
"hi linenumber 250 237\n"
"hi statusline 252 239\n"
"hi errormsg 5/3/0\n"
"hi infomsg 0/4/5\n"
"hi tabbar 250 237\n"
"hi activetab 255\n"
"hi inactivetab 250 237\n"
"\n"
"hi text\n"
"hi code\n"
"hi ident\n"
"hi keyword 5/5/4\n"
"hi type 0/4/5\n"
"hi label 5/5/2\n"
"hi notice 5/3/0\n"
"hi numeric 5/2/5\n"
"hi constant 5/2/5\n"
"hi char 5/2/5\n"
"hi string 3/3/2\n"
"hi special 3/5/2\n"
"hi comment 242\n"
"hi error 232 216\n"
"hi variable 0/4/5\n"
"\n"
"hi c.preproc 0/3/5\n"
"hi c.preproccond 27\n"
"hi css.id 0/2/5\n"
"hi css.class 0/3/5\n"
"hi css.pseudoclass 5/2/5\n"
"hi css.pseudoelement 0/5/0\n"
"hi diff.header 255\n"
"hi diff.chunk 250 239\n"
"hi diff.added 0/3/5\n"
"hi diff.removed 5/1/1\n"
"hi diff.context keep keep\n"
"hi gitcommit.added 0/3/5\n"
"hi gitcommit.modified 202\n"
"hi gitcommit.untracked 202\n"
"hi gitcommit.newfile 0/4/0\n"
"hi go.builtin 0/3/5\n"
"hi html.tag 3/5/2\n"
"hi html.attr 0/3/5\n"
"hi javascript.regexp 5/2/5\n"
"hi make.builtin 5/5/4\n"
"hi sh.builtin 5/5/4\n"
"hi xml.tag 3/5/2\n"
"hi xml.attr 0/3/5\n"
"hi ini.section bold\n"
;

static CONFIG_SECTION const char builtin_syntax_awk[] =
"syntax .awk-esc\n"
"\n"
"state special\n"
"char 0-3 oct1\n"
"char 4-7 oct2\n"
"char x hex0\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex0 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F END error\n"
"noeat END\n"
"\n"
"syntax awk\n"
"\n"
"state code\n"
"char \134\042 string\n"
"char / regexp\n"
"char # comment\n"
"char -b a-zA-Z_ ident\n"
"eat this\n"
"\n"
"state string\n"
"char \134\134 dqescape\n"
"char \134\042 code string\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state regexp\n"
"char \134\134 regexpescape\n"
"char / code regexp\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state dqescape special\n"
"char abfnrtv\134\134\134\042 string special\n"
"noeat .awk-esc:string\n"
"\n"
"state regexpescape special\n"
"char abfnrtv.[({*+?|^/\134\134\134$ regexp special\n"
"noeat .awk-esc:regexp\n"
"\n"
"state comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist builtin code\n"
"inlist pattern code\n"
"inlist variable code\n"
"inlist gawk-keyword code\n"
"inlist gawk-builtin code\n"
"inlist gawk-variable code\n"
"noeat code\n"
"\n"
"list pattern BEGIN END\n"
"\n"
"list keyword \134\n"
"break continue delete do else exit for function getline if next \134\n"
"print printf return while\n"
"\n"
"list gawk-keyword \134\n"
"func nextfile\n"
"\n"
"list builtin \134\n"
"atan2 close cos exp fflush gsub index int length log match rand sin \134\n"
"split sprintf sqrt srand sub substr system\n"
"\n"
"list gawk-builtin \134\n"
"and asort bindtextdomain compl dcgettext gensub lshift mktime or \134\n"
"rshift strftime strtonum systime tolower toupper xor\n"
"\n"
"list variable \134\n"
"ARGC ARGV FILENAME FNR FS NF NR OFMT OFS ORS RLENGTH RS RSTART SUBSEP\n"
"\n"
"list gawk-variable \134\n"
"ARGIND BINMODE CONVFMT ENVIRON ERRNO FIELDWIDTHS IGNORECASE LINT \134\n"
"PROCINFO RLENGTH RT TEXTDOMAIN\n"
"\n"
"default string regexp\n"
"default keyword gawk-keyword pattern\n"
"default builtin gawk-builtin\n"
"default variable gawk-variable\n"
;

static CONFIG_SECTION const char builtin_syntax_c[] =
"require c-comment\n"
"require c-uchar\n"
"\n"
"syntax .c-esc\n"
"\n"
"state start special\n"
"char \042abfnrtv'\134\134\134\042\042 END special\n"
"char 0-3 oct1\n"
"char 4-7 oct2\n"
"char x hex0\n"
"char u .c-uchar4:END special\n"
"char U .c-uchar8:END special\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex0 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F END error\n"
"noeat END\n"
"\n"
"syntax .c-string\n"
"\n"
"state string\n"
"char '\042' END string\n"
"char \042\134n\042 END error\n"
"char \042\134\134\042 esc\n"
"eat this\n"
"\n"
"state esc special\n"
"char \042\134n\042 string\n"
"noeat .c-esc:string\n"
"\n"
"syntax .c-char\n"
"\n"
"state char\n"
"char \042'\134n\042 END error\n"
"char \134\134 .c-esc:char-end\n"
"eat char-end\n"
"\n"
"state char-end char\n"
"char \042'\042 END char\n"
"eat END error\n"
"\n"
"syntax .cpp-comment\n"
"\n"
"state comment\n"
"char \042\134n\042 END\n"
"char \134\134 backslash\n"
"eat this\n"
"\n"
"state backslash comment\n"
"char \042\134n\042 comment\n"
"noeat comment\n"
"\n"
"syntax c\n"
"\n"
"state start code\n"
"char \042 \134t\042 this\n"
"char # preproc\n"
"char -b a-z_ ident-label\n"
"char -b A-Z ident-upper-label\n"
"noeat c\n"
"\n"
"state preproc\n"
"char \042 \134t\042 this\n"
"char -b a-zA-Z_ preproc-ident\n"
"noeat preproc-misc\n"
"\n"
"state preproc-ident preproc\n"
"char -b a-zA-Z0-9_ this\n"
"bufis 'include' preproc-include\n"
"inlist preproccond preproccond\n"
"noeat preproc-misc\n"
"\n"
"state preproccond\n"
"recolor preproccond 100\n"
"noeat preproc-misc\n"
"\n"
"state preproc-misc preproc\n"
"char \042\134n\042 start\n"
"char \042\134\134\042 preproc-cont\n"
"char \134\042 .c-string:this\n"
"char \134' .c-char:this\n"
"str '/*' .c-comment:this\n"
"str '//' .cpp-comment:start\n"
"eat this\n"
"\n"
"state preproc-include preproc\n"
"char \042 \134t\042 this\n"
"char \042\134n\042 start\n"
"char \042\134\134\042 preproc-cont\n"
"char '\042' local-include\n"
"char '<' system-include\n"
"noeat preproc-misc\n"
"\n"
"state preproc-cont preproc\n"
"char \042\134n\042 preproc-misc\n"
"noeat preproc-misc\n"
"\n"
"state local-include string\n"
"char '\042' end-include string\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state system-include string\n"
"char '>' end-include string\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state end-include preproc\n"
"char \042\134n\042 start\n"
"char \042 \134t\042 this\n"
"str '/*' .c-comment:this\n"
"str '//' .cpp-comment:start\n"
"eat preproc-error\n"
"\n"
"state preproc-error error\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state c code\n"
"char -b a-z_ ident\n"
"char -b A-Z ident-upper\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \134\042 .c-string:this\n"
"char \134' .c-char:this\n"
"char \042\134n\042 start\n"
"char ';' semicolon\n"
"str '/*' .c-comment:this\n"
"str '//' .cpp-comment:start\n"
"eat this\n"
"\n"
"state semicolon code\n"
"char \042 \134t\042 this\n"
"char -b a-zA-Z_ ident-label\n"
"noeat c\n"
"\n"
"state ident-label ident\n"
"char -b a-zA-Z0-9_ this\n"
"char -b : label\n"
"noeat -b ident\n"
"\n"
"state label\n"
"recolor label\n"
"noeat c\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword c\n"
"inlist c11-keyword c\n"
"inlist type c\n"
"inlist common-typedef c\n"
"inlist posix-type c\n"
"inlist constant c\n"
"inlist cpp-keyword c\n"
"noeat c\n"
"\n"
"state ident-upper ident\n"
"char -b a-z class-name\n"
"char -b A-Z0-9_ ident\n"
"noeat c\n"
"\n"
"state class-name\n"
"recolor class-name\n"
"char a-zA-Z0-9_ this\n"
"noeat c\n"
"\n"
"state ident-upper-label ident\n"
"char -b a-z class-name-label\n"
"char -b A-Z0-9_ ident-label\n"
"char -b : label\n"
"noeat c\n"
"\n"
"state class-name-label class-name\n"
"char -b a-zA-Z0-9_ this\n"
"char -b : label\n"
"noeat -b class-name\n"
"\n"
"state zero numeric\n"
"char bB bin\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat check-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state bin numeric\n"
"char 01 this\n"
"noeat check-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"char . hex-float\n"
"noeat check-suffix\n"
"\n"
"state hex-float numeric\n"
"char 0-9a-fA-F this\n"
"char Pp hex-float-p\n"
"char a-zA-Z_+- error-ident\n"
"noeat c\n"
"\n"
"state hex-float-p numeric\n"
"char 0-9+- hex-float-exp\n"
"char a-zA-Z_ error-ident\n"
"noeat c\n"
"\n"
"state hex-float-exp numeric\n"
"char 0-9 this\n"
"char fFlL float-suffix\n"
"char a-zA-Z_ error-ident\n"
"noeat c\n"
"\n"
"state check-suffix error\n"
"char -b a-zA-Z0-9_ this\n"
"inlist numeric-suffix c numeric\n"
"noeat c\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat c\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char fFlL float-suffix\n"
"char a-zA-Z_ error-ident\n"
"noeat c\n"
"\n"
"state float-suffix numeric\n"
"char a-zA-Z0-9_ error-ident\n"
"noeat c\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"char a-zA-Z_ error-ident\n"
"noeat c\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"char a-zA-Z_ error-ident\n"
"noeat c\n"
"\n"
"state error-ident error\n"
"char a-zA-Z0-9_ this\n"
"noeat c\n"
"\n"
"list keyword \134\n"
"if else for while do continue switch case break default return goto \134\n"
"asm const static inline register extern volatile auto restrict sizeof \134\n"
"typedef\n"
"\n"
"list c11-keyword \134\n"
"_Alignas _Alignof _Noreturn \134\n"
"alignas alignof noreturn\n"
"\n"
"list type \134\n"
"char short int long float double void signed unsigned enum struct union \134\n"
"bool size_t va_list jmp_buf FILE _Bool _Complex _Imaginary \134\n"
"clock_t div_t double_t fenv_t fexcept_t float_t fpos_t imaxdiv_t ldiv_t \134\n"
"lldiv_t mbstate_t ptrdiff_t sig_atomic_t time_t wchar_t wctrans_t wint_t \134\n"
"int8_t uint8_t int_fast8_t uint_fast8_t int_least8_t uint_least8_t \134\n"
"int16_t uint16_t int_fast16_t uint_fast16_t int_least16_t uint_least16_t \134\n"
"int32_t uint32_t int_fast32_t uint_fast32_t int_least32_t uint_least32_t \134\n"
"int64_t uint64_t int_fast64_t uint_fast64_t int_least64_t uint_least64_t \134\n"
"intptr_t uintptr_t intmax_t uintmax_t __int128 char32_t char16_t char8_t\n"
"\n"
"list common-typedef \134\n"
"u8 u16 u32 u64 u128 i8 i16 i32 i64 i128 s8 s16 s32 s64 s128 \134\n"
"uchar ushort uint ulong ullong u_char u_short u_int u_long u_llong\n"
"\n"
"list posix-type \134\n"
"DIR blkcnt_t blksize_t clockid_t dev_t fsblkcnt_t fsfilcnt_t gid_t glob_t \134\n"
"iconv_t id_t ino_t key_t locale_t mcontext_t mode_t nlink_t off_t pid_t \134\n"
"regex_t regmatch_t regoff_t siginfo_t sigjmp_buf sigset_t ssize_t stack_t \134\n"
"suseconds_t timer_t ucontext_t uid_t \134\n"
"trace_attr_t trace_event_id_t trace_event_set_t trace_id_t \134\n"
"posix_spawn_file_actions_t posix_spawnattr_t \134\n"
"pthread_attr_t pthread_barrier_t pthread_barrierattr_t \134\n"
"pthread_cond_t pthread_condattr_t pthread_key_t pthread_mutex_t \134\n"
"pthread_mutexattr_t pthread_once_t pthread_rwlock_t \134\n"
"pthread_rwlockattr_t pthread_spinlock_t pthread_t\n"
"\n"
"list constant \134\n"
"NULL stdin stdout stderr false true \134\n"
"E2BIG EACCES EADDRINUSE EADDRNOTAVAIL EAFNOSUPPORT EAGAIN EALREADY \134\n"
"EBADF EBADMSG EBUSY ECANCELED ECHILD ECONNABORTED ECONNREFUSED \134\n"
"ECONNRESET EDEADLK EDESTADDRREQ EDOM EDQUOT EEXIST EFAULT EFBIG \134\n"
"EHOSTUNREACH EIDRM EILSEQ EINPROGRESS EINTR EINVAL EIO EISCONN \134\n"
"EISDIR ELOOP EMFILE EMLINK EMSGSIZE EMULTIHOP ENAMETOOLONG ENETDOWN \134\n"
"ENETRESET ENETUNREACH ENFILE ENOBUFS ENODATA ENODEV ENOENT ENOEXEC \134\n"
"ENOLCK ENOLINK ENOMEM ENOMSG ENOPROTOOPT ENOSPC ENOSR ENOSTR ENOSYS \134\n"
"ENOTCONN ENOTDIR ENOTEMPTY ENOTRECOVERABLE ENOTSOCK ENOTSUP ENOTTY \134\n"
"ENXIO EOPNOTSUPP EOVERFLOW EOWNERDEAD EPERM EPIPE EPROTO \134\n"
"EPROTONOSUPPORT EPROTOTYPE ERANGE EROFS ESPIPE ESRCH ESTALE ETIME \134\n"
"ETIMEDOUT ETXTBSY EWOULDBLOCK EXDEV ENOTBLK\n"
"\n"
"list preproccond \134\n"
"elif else endif if ifdef ifndef\n"
"\n"
"list -i numeric-suffix \134\n"
"ULL UL U LLU LU LL L\n"
"\n"
"list cpp-keyword \134\n"
"and and_eq bitand bitor catch class compl const_cast concept \134\n"
"consteval constexpr constinit const_cast \134\n"
"co_await co_return co_yield \134\n"
"decltype delete dynamic_cast explicit export friend \134\n"
"mutable namespace new noexcept not not_eq nullptr \134\n"
"operator or or_eq \134\n"
"private protected public \134\n"
"reinterpret_cast requires static_cast template this throw try \134\n"
"typeid typename using virtual xor xor_eq\n"
"\n"
"default ident class-name\n"
"default keyword c11-keyword cpp-keyword\n"
"default preproc preproccond\n"
"default type posix-type\n"
;

static CONFIG_SECTION const char builtin_syntax_coccinelle[] =
"require c-comment\n"
"\n"
"syntax .coccinelle-meta\n"
"\n"
"state decl code\n"
"char -b A-Za-z_ ident\n"
"char '\042' string\n"
"char / maybe-comment\n"
"str @@ END meta-header\n"
"eat this\n"
"\n"
"state string\n"
"char '\042' decl string\n"
"eat this\n"
"\n"
"state maybe-comment comment\n"
"char / line-comment\n"
"char * .c-comment:decl\n"
"recolor code 1\n"
"noeat decl\n"
"\n"
"state line-comment comment\n"
"char \042\134n\042 decl\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword decl\n"
"noeat decl\n"
"\n"
"list keyword \134\n"
"fresh identifier metavariable field parameter type statement \134\n"
"declaration initialiser initializer local global idexpression \134\n"
"expression constant format assignment binary unary operator \134\n"
"position any symbol typedef attribute declarer iterator\n"
"\n"
"syntax coccinelle\n"
"\n"
"state line-start code\n"
"char \042 \134t\134n\042 this\n"
"char -b @ maybe-meta-header\n"
"char + code added\n"
"char -- - code removed\n"
"noeat code\n"
"\n"
"state code\n"
"char \042\134n\042 line-start\n"
"char / maybe-comment\n"
"eat this\n"
"\n"
"state maybe-comment comment\n"
"char / line-comment\n"
"char * .c-comment:code\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state line-comment comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state maybe-meta-header code\n"
"char -b @ meta-header\n"
"char -bn \042@\134n\042 this\n"
"eat line-start\n"
"\n"
"state meta-header\n"
"recolor meta-header\n"
"noeat .coccinelle-meta:code\n"
"\n"
"default keyword meta-keyword\n"
"default diff.header meta-header\n"
"default diff.added added\n"
"default diff.removed removed\n"
;

static CONFIG_SECTION const char builtin_syntax_config[] =
"\n"
"syntax config\n"
"\n"
"state code\n"
"char # comment\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 code\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_css[] =
"require c-comment\n"
"\n"
"syntax .css-statementerror\n"
"\n"
"state error\n"
"char \042;\134n\042 END code\n"
"eat this\n"
"\n"
"syntax .css-selectorerror\n"
"\n"
"state error\n"
"char -n \042 \134t\134n\134r{\042 this\n"
"noeat END\n"
"\n"
"syntax .css-hex\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"noeat ws\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F hex3\n"
"noeat ws\n"
"\n"
"state hex3 special\n"
"char 0-9a-fA-F hex4\n"
"noeat ws\n"
"\n"
"state hex4 special\n"
"char 0-9a-fA-F hex5\n"
"noeat ws\n"
"\n"
"state hex5 special\n"
"char 0-9a-fA-F ws special\n"
"noeat ws\n"
"\n"
"state ws\n"
"char \042\134t\134n\134r \042 END special\n"
"noeat END\n"
"\n"
"syntax .css-dq\n"
"\n"
"state string\n"
"char \134\042 END string\n"
"char \134\134 esc\n"
"char \042\134n\042 END error\n"
"eat this\n"
"\n"
"state esc special\n"
"char \042\134n\134\134\134\042\042 string special\n"
"char 0-9a-fA-F .css-hex:string\n"
"eat string error\n"
"\n"
"syntax .css-sq\n"
"\n"
"state string\n"
"char \134' END string\n"
"char \134\134 esc\n"
"char \042\134n\042 END error\n"
"eat this\n"
"\n"
"state esc special\n"
"char \042\134n\134\134'\042 string special\n"
"char 0-9a-fA-F .css-hex:string\n"
"eat string error\n"
"\n"
"syntax .css-ident\n"
"\n"
"state ident\n"
"char \042a-zA-Z0-9\134xa1-\134xff_-\042 this\n"
"noeat END\n"
"\n"
"syntax .css-attributeselector\n"
"\n"
"state attributeselector code\n"
"char -b a-zA-Z attribute\n"
"noeat close\n"
"\n"
"state attribute\n"
"char -b a-zA-Z this\n"
"char \042|~\042 op\n"
"char = value code\n"
"noeat close\n"
"\n"
"state op code\n"
"char = value code\n"
"eat END error\n"
"\n"
"state value\n"
"char \134\042 .css-dq:close\n"
"char \134' .css-sq:close\n"
"char a-zA-Z_- .css-ident:close\n"
"noeat close\n"
"\n"
"state close\n"
"char ] END code\n"
"eat END error\n"
"\n"
"syntax .css-url\n"
"\n"
"state url\n"
"char \134\042 .css-dq:close\n"
"char \134' .css-sq:close\n"
"noeat plain\n"
"\n"
"state plain code\n"
"char ) END url\n"
"char \042\134n\042 END error\n"
"eat this\n"
"\n"
"state close\n"
"char ) END url\n"
"eat END error\n"
"\n"
"syntax .css-import\n"
"\n"
"state import atkeyword\n"
"char \042\134t\134n \042 arg\n"
"noeat error\n"
"\n"
"state arg code\n"
"char \042\134t\134n \042 this\n"
"char \134\042 .css-dq:medialist\n"
"char \134' .css-sq:medialist\n"
"str -i \042url(\042 .css-url:medialist\n"
"noeat error\n"
"\n"
"state medialist\n"
"char \134; END code\n"
"eat this\n"
"\n"
"state error\n"
"noeat .css-statementerror:END\n"
"\n"
"syntax .css-namespace\n"
"\n"
"state namespace atkeyword\n"
"char \042\134t\134n \042 arg1\n"
"noeat error\n"
"\n"
"state arg1 code\n"
"char \042\134t\134n \042 this\n"
"str -i \042url(\042 .css-url:namespace-end\n"
"char a-zA-Z prefix\n"
"noeat arg2\n"
"\n"
"state prefix code\n"
"char a-zA-Z0-9- this\n"
"char \042\134t\134n \042 arg2\n"
"noeat error\n"
"\n"
"state arg2 code\n"
"char \042\134t\134n \042 this\n"
"char \134\042 .css-dq:namespace-end\n"
"char \134' .css-sq:namespace-end\n"
"str -i \042url(\042 .css-url:namespace-end\n"
"noeat error\n"
"\n"
"state namespace-end\n"
"char \042\134t\134n \042 this\n"
"char \134; END code\n"
"noeat error\n"
"\n"
"state error\n"
"noeat .css-statementerror:END\n"
"\n"
"syntax css\n"
"\n"
"state verybeginning\n"
"str -i '@charset ' charset\n"
"noeat start\n"
"\n"
"state charset atkeyword\n"
"char \134\042 .css-dq:atend\n"
"eat .css-statementerror:start\n"
"\n"
"state atend code\n"
"char \042\134t\134n \042 this\n"
"char \134; start\n"
"eat .css-statementerror:start\n"
"\n"
"state start code\n"
"char \042 \134t\134n\042 this\n"
"char -b a-zA-Z maybe-element\n"
"char . class\n"
"char # id\n"
"char -b : pseudo\n"
"char [ .css-attributeselector:this\n"
"char { block\n"
"char 0-9_- .css-selectorerror:this\n"
"str \042/*\042 .c-comment:this\n"
"char -b @ atrule\n"
"eat this\n"
"\n"
"state maybe-element\n"
"char -b a-zA-Z0-9 this\n"
"inlist element start tag\n"
"char _- .css-selectorerror:start\n"
"noeat start\n"
"\n"
"state pseudo code\n"
"char -b a-zA-Z0-9:- this\n"
"inlist pseudoclass start\n"
"inlist exprpseudo nth pseudoclass\n"
"inlist pseudoelement start\n"
"inlist pagepseudoclass start pseudoclass\n"
"bufis -i :lang complexpseudo\n"
"bufis -i :not complexpseudo\n"
"noeat start\n"
"\n"
"state complexpseudo pseudoclass\n"
"char ( complexexpr\n"
"eat .css-selectorerror:start\n"
"\n"
"state nth\n"
"char ( nthexpr\n"
"eat .css-selectorerror:start\n"
"\n"
"state nthexpr expr\n"
"char a-z0-9+- this\n"
"char ) start expr\n"
"eat .css-selectorerror:start\n"
"\n"
"state complexexpr expr\n"
"char ) start expr\n"
"char -n \042\134n\042 this\n"
"noeat start\n"
"\n"
"state class\n"
"char a-zA-Z0-9_- this\n"
"noeat start\n"
"\n"
"state id\n"
"char a-zA-Z0-9_- this\n"
"noeat start\n"
"\n"
"state atrule code\n"
"char -b a-zA-Z0-9_- this\n"
"inlist atkeyword start\n"
"bufis -i \042@import\042 .css-import:start atkeyword\n"
"bufis -i \042@namespace\042 .css-namespace:start atkeyword\n"
"bufis -i @media mediatypes atkeyword\n"
"noeat start\n"
"\n"
"state mediatypes code\n"
"char { start\n"
"eat this\n"
"\n"
"state block code\n"
"char \042 \134t\134n;\042 this\n"
"char -b a-zA-Z- property\n"
"char 0-9_- property-error\n"
"char } start\n"
"str \042/*\042 .c-comment:this\n"
"eat this\n"
"\n"
"state property code\n"
"char -b a-zA-Z- this\n"
"char 0-9_ property-error\n"
"inlist property property-end\n"
"inlist fontfaceproperty property-end property\n"
"noeat property-end\n"
"\n"
"state property-end code\n"
"char : values\n"
"char \042 \134t\134n\042 this\n"
"char \042;\042 block\n"
"char } start\n"
"eat property-error\n"
"\n"
"state values code\n"
"char \042 \134t\134n\042 this\n"
"char 0-9 int\n"
"char -- - minus\n"
"char # hexcolor\n"
"char \042;\042 block\n"
"char \134\042 .css-dq:this\n"
"char \134' .css-sq:this\n"
"str -i \042url(\042 .css-url:this\n"
"char -b a-zA-Z_ value\n"
"char } start\n"
"str \042/*\042 .c-comment:this\n"
"eat this\n"
"\n"
"state minus numeric\n"
"char 0-9 int\n"
"char . float\n"
"noeat values\n"
"\n"
"state int numeric\n"
"char 0-9 this\n"
"char . float\n"
"char -b a-zA-Z% unit\n"
"noeat values\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char -b a-zA-Z% unit\n"
"noeat values\n"
"\n"
"state unit error\n"
"char -b a-zA-Z% this\n"
"inlist unit values numeric\n"
"char \042;\042 block\n"
"char } start\n"
"eat value-error\n"
"\n"
"state value code\n"
"char -b a-zA-Z0-9_- this\n"
"inlist value values\n"
"inlist color values\n"
"inlist func func value\n"
"noeat values\n"
"\n"
"state hexcolor color\n"
"char 0-9a-fA-F this\n"
"char g-zG-Z_- value-error\n"
"noeat values\n"
"\n"
"state func code\n"
"char \042 \134t\042 this\n"
"char ( params\n"
"eat value-error\n"
"\n"
"state params code\n"
"char ) values\n"
"char \042;\042 block\n"
"char } start\n"
"eat this\n"
"\n"
"state property-error error\n"
"char a-zA-Z0-9_- this\n"
"noeat property\n"
"\n"
"state value-error error\n"
"char a-zA-Z0-9_- this\n"
"noeat values\n"
"\n"
"list -i element \134\n"
"a abbr acronym address area b base bdo big blockquote body br \134\n"
"button caption cite code col colgroup dd del dfn div dl dt em \134\n"
"fieldset form h1 h2 h3 h4 h5 h6 head hr html i iframe img input \134\n"
"ins kbd label legend li link map meta noscript object ol optgroup \134\n"
"option p param pre q samp script select small span strong style \134\n"
"sub sup table tbody td textarea tfoot th thead title tr tt ul var \134\n"
"\134\n"
"article aside audio canvas command datalist details embed figure \134\n"
"footer header hgroup keygen main mark meter nav output progress ruby \134\n"
"section time video wbr\n"
"\n"
"list -i property \134\n"
"align-content align-items alignment-baseline align-self all \134\n"
"animation animation-delay animation-direction animation-duration \134\n"
"animation-fill-mode animation-iteration-count animation-name \134\n"
"animation-play-state animation-timing-function appearance azimuth \134\n"
"background background-attachment background-blend-mode \134\n"
"background-clip background-color background-image \134\n"
"background-image-transform background-origin background-position \134\n"
"background-repeat background-size baseline-shift block-size \134\n"
"block-step block-step-align block-step-insert block-step-round \134\n"
"block-step-size bookmark-label bookmark-level bookmark-state border \134\n"
"border-block border-block-color border-block-end \134\n"
"border-block-end-color border-block-end-style border-block-end-width \134\n"
"border-block-start border-block-start-color border-block-start-style \134\n"
"border-block-start-width border-block-style border-block-width \134\n"
"border-bottom border-bottom-color border-bottom-left-radius \134\n"
"border-bottom-right-radius border-bottom-style border-bottom-width \134\n"
"border-boundary border-collapse border-color border-image \134\n"
"border-image-outset border-image-repeat border-image-slice \134\n"
"border-image-source border-image-transform border-image-width \134\n"
"border-inline border-inline-color border-inline-end \134\n"
"border-inline-end-color border-inline-end-style \134\n"
"border-inline-end-width border-inline-start \134\n"
"border-inline-start-color border-inline-start-style \134\n"
"border-inline-start-width border-inline-style border-inline-width \134\n"
"border-left border-left-color border-left-style border-left-width \134\n"
"border-radius border-right border-right-color border-right-style \134\n"
"border-right-width border-spacing border-style border-top \134\n"
"border-top-color border-top-left-radius border-top-right-radius \134\n"
"border-top-style border-top-width border-width bottom \134\n"
"box-decoration-break box-shadow box-sizing box-snap break-after \134\n"
"break-before break-inside caption-side caret caret-animation \134\n"
"caret-color caret-shape chains clear clip clip-path clip-rule color \134\n"
"color-adjust color-interpolation-filters column-count column-fill \134\n"
"column-gap column-rule column-rule-color column-rule-style \134\n"
"column-rule-width columns column-span column-width contain content \134\n"
"continue counter-increment counter-reset counter-set cue cue-after \134\n"
"cue-before cursor direction display dominant-baseline elevation \134\n"
"empty-cells fill fill-break fill-color fill-image fill-opacity \134\n"
"fill-origin fill-position fill-repeat fill-rule fill-size filter \134\n"
"flex flex-basis flex-direction flex-flow flex-grow flex-shrink \134\n"
"flex-wrap float float-defer float-offset float-reference flood-color \134\n"
"flood-opacity flow flow-from flow-into font font-family \134\n"
"font-feature-settings font-kerning font-language-override \134\n"
"font-max-size font-min-size font-optical-sizing font-palette \134\n"
"font-presentation font-size font-size-adjust font-stretch font-style \134\n"
"font-synthesis font-variant font-variant-alternates \134\n"
"font-variant-caps font-variant-east-asian font-variant-ligatures \134\n"
"font-variant-numeric font-variant-position font-variation-settings \134\n"
"font-weight footnote-display footnote-policy gap \134\n"
"glyph-orientation-vertical grid grid-area grid-auto-columns \134\n"
"grid-auto-flow grid-auto-rows grid-column grid-column-end \134\n"
"grid-column-gap grid-column-start grid-gap grid-row grid-row-end \134\n"
"grid-row-gap grid-row-start grid-template grid-template-areas \134\n"
"grid-template-columns grid-template-rows hanging-punctuation height \134\n"
"hyphenate-character hyphenate-limit-chars hyphenate-limit-last \134\n"
"hyphenate-limit-lines hyphenate-limit-zone hyphens image-orientation \134\n"
"image-resolution initial-letter initial-letter-align \134\n"
"initial-letter-wrap inline-size inset inset-block inset-block-end \134\n"
"inset-block-start inset-inline inset-inline-end inset-inline-start \134\n"
"isolation justify-content justify-items justify-self left \134\n"
"letter-spacing lighting-color line-break line-grid line-height \134\n"
"line-height-step line-snap list-style list-style-image \134\n"
"list-style-position list-style-type margin margin-block \134\n"
"margin-block-end margin-block-start margin-bottom margin-inline \134\n"
"margin-inline-end margin-inline-start margin-left margin-right \134\n"
"margin-top marker marker-end marker-knockout-left \134\n"
"marker-knockout-right marker-mid marker-pattern marker-segment \134\n"
"marker-side marker-start marquee-direction marquee-loop \134\n"
"marquee-speed marquee-style mask mask-border mask-border-mode \134\n"
"mask-border-outset mask-border-repeat mask-border-slice \134\n"
"mask-border-source mask-border-width mask-clip mask-composite \134\n"
"mask-image mask-mode mask-origin mask-position mask-repeat mask-size \134\n"
"mask-type max-block-size max-height max-inline-size max-lines \134\n"
"max-width min-block-size min-height min-inline-size min-width \134\n"
"mix-blend-mode nav-down nav-left nav-right nav-up object-fit \134\n"
"object-position offset offset-after offset-anchor offset-before \134\n"
"offset-distance offset-end offset-path offset-position offset-rotate \134\n"
"offset-start opacity order orphans outline outline-color \134\n"
"outline-offset outline-style outline-width overflow overflow-style \134\n"
"overflow-wrap overflow-x overflow-y padding padding-block \134\n"
"padding-block-end padding-block-start padding-bottom padding-inline \134\n"
"padding-inline-end padding-inline-start padding-left padding-right \134\n"
"padding-top page page-break-after page-break-before \134\n"
"page-break-inside pause pause-after pause-before pitch pitch-range \134\n"
"place-content place-items place-self play-during position \134\n"
"presentation-level quotes region-fragment resize rest rest-after \134\n"
"rest-before richness right rotation rotation-point row-gap \134\n"
"ruby-align ruby-merge ruby-position running scrollbar-gutter \134\n"
"scroll-behavior scroll-padding scroll-padding-block \134\n"
"scroll-padding-block-end scroll-padding-block-start \134\n"
"scroll-padding-bottom scroll-padding-inline \134\n"
"scroll-padding-inline-end scroll-padding-inline-start \134\n"
"scroll-padding-left scroll-padding-right scroll-padding-top \134\n"
"scroll-snap-align scroll-snap-margin scroll-snap-margin-block \134\n"
"scroll-snap-margin-block-end scroll-snap-margin-block-start \134\n"
"scroll-snap-margin-bottom scroll-snap-margin-inline \134\n"
"scroll-snap-margin-inline-end scroll-snap-margin-inline-start \134\n"
"scroll-snap-margin-left scroll-snap-margin-right \134\n"
"scroll-snap-margin-top scroll-snap-stop scroll-snap-type \134\n"
"shape-image-threshold shape-inside shape-margin shape-outside size \134\n"
"speak speak-as speak-header speak-numeral speak-punctuation \134\n"
"speech-rate stress string-set stroke stroke-align stroke-alignment \134\n"
"stroke-break stroke-color stroke-dashadjust stroke-dasharray \134\n"
"stroke-dashcorner stroke-dash-corner stroke-dash-justify \134\n"
"stroke-dashoffset stroke-image stroke-linecap stroke-linejoin \134\n"
"stroke-miterlimit stroke-opacity stroke-origin stroke-position \134\n"
"stroke-repeat stroke-size stroke-width table-layout tab-size \134\n"
"text-align text-align-all text-align-last text-combine-upright \134\n"
"text-decoration text-decoration-color text-decoration-line \134\n"
"text-decoration-skip text-decoration-style text-emphasis \134\n"
"text-emphasis-color text-emphasis-position text-emphasis-style \134\n"
"text-indent text-justify text-orientation text-overflow text-shadow \134\n"
"text-space-collapse text-space-trim text-spacing text-transform \134\n"
"text-underline-position text-wrap top transform transform-box \134\n"
"transform-origin transition transition-delay transition-duration \134\n"
"transition-property transition-timing-function unicode-bidi \134\n"
"user-select vertical-align visibility voice-balance voice-duration \134\n"
"voice-family voice-pitch voice-range voice-rate voice-stress \134\n"
"voice-volume volume white-space widows width will-change word-break \134\n"
"word-spacing word-wrap wrap-after wrap-before wrap-flow wrap-inside \134\n"
"wrap-through writing-mode z-index\n"
"\n"
"list -i value \134\n"
"absolute always armenian auto avoid baseline bidi-override blink \134\n"
"block bold bolder both bottom capitalize center circle \134\n"
"cjk-ideographic collapse compact condensed crop cross crosshair \134\n"
"dashed decimal decimal-leading-zero default disc dotted double \134\n"
"e-resize embed expanded extra-condensed extra-expanded fixed \134\n"
"georgian groove hebrew help hidden hide hiragana hiragana-iroha \134\n"
"inline inline-table inset inside italic justify katakana \134\n"
"katakana-iroha landscape large larger left lighter line-through \134\n"
"list-item lower-alpha lower-greek lower-latin lower-roman lowercase \134\n"
"ltr marker medium middle move n-resize narrower ne-resize no-repeat \134\n"
"none normal nowrap nw-resize oblique outset outside overline pointer \134\n"
"portrait pre relative repeat repeat-x repeat-y ridge right rtl run-in \134\n"
"s-resize scroll se-resize semi-condensed semi-expanded separate show \134\n"
"small small-caps smaller solid square static sub super sw-resize \134\n"
"table table-caption table-cell table-column table-column-group \134\n"
"table-footer-group table-header-group table-row table-row-group text \134\n"
"text-bottom text-top thick thin top ultra-condensed ultra-expanded \134\n"
"underline upper-alpha upper-latin upper-roman uppercase visible \134\n"
"w-resize wait wider x-large x-small xx-large xx-small\n"
"\n"
"list -i color \134\n"
"aqua black blue fuchsia gray green lime maroon navy olive \134\n"
"purple red silver teal white yellow\n"
"\n"
"list -i pseudoclass \134\n"
":active :checked :disabled :empty :enabled :first-child \134\n"
":first-of-type :focus :focus-visible :focus-within :hover \134\n"
":last-child :last-of-type :link :only-child :only-of-type \134\n"
":root :target :visited\n"
"\n"
"list -i exprpseudo :nth-child :nth-last-child :nth-last-of-type :nth-of-type\n"
"\n"
"list -i pseudoelement \134\n"
":after :before :first-letter :first-line \134\n"
"::after ::before ::first-letter ::first-line \134\n"
"::selection\n"
"\n"
"list -i pagepseudoclass \134\n"
":left :right :first\n"
"\n"
"list -i fontfaceproperty \134\n"
"font-family font-stretch font-style font-weight src unicode-range\n"
"\n"
"list -i unit \134\n"
"% fr \134\n"
"ch cm em ex in mm pc pt px rem vh vw vmin vmax \134\n"
"deg grad rad turn \134\n"
"ms s \134\n"
"hz khz \134\n"
"dpcm dpi dppx\n"
"\n"
"list -i func \134\n"
"attr clip counter rect rgb\n"
"\n"
"list -i atkeyword @page @font-face\n"
"\n"
"default keyword property\n"
"default type class id pseudoclass pseudoelement attribute\n"
"default special expr\n"
"default constant value color url\n"
"default special atkeyword\n"
;

static CONFIG_SECTION const char builtin_syntax_d[] =
"require c-comment\n"
"\n"
"syntax .d-esc\n"
"\n"
"state start special\n"
"char \042abfnrtv'\134\134\134\042\042 END special\n"
"char 0-3 oct1\n"
"char 4-7 oct2\n"
"char x hex0\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex0 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F END error\n"
"noeat END\n"
"\n"
"syntax .d-string\n"
"\n"
"state string\n"
"char \042\134\042\042 END string\n"
"char \042\134n\042 END error\n"
"char \042\134\134\042 .d-esc:this\n"
"eat this\n"
"\n"
"syntax .d-char\n"
"\n"
"state char\n"
"char \042'\134n\042 END error\n"
"char \134\134 .d-esc:char-end\n"
"eat char-end\n"
"\n"
"state char-end char\n"
"char \042'\042 END char\n"
"eat END error\n"
"\n"
"syntax .d-line-comment\n"
"\n"
"state comment\n"
"char \042\134n\042 END\n"
"char \134\134 backslash\n"
"eat this\n"
"\n"
"state backslash comment\n"
"char \042\134n\042 comment\n"
"noeat comment\n"
"\n"
"syntax d\n"
"\n"
"state start code\n"
"char \042 \134t\042 this\n"
"char -b a-z_ ident-label\n"
"char -b A-Z ident-upper-label\n"
"noeat code\n"
"\n"
"state code code\n"
"char -b a-z_ ident\n"
"char -b A-Z ident-upper\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \134\042 .d-string:this\n"
"char \134' .d-char:this\n"
"char \042\134n\042 start\n"
"char ';' semicolon\n"
"str \042/*\042 .c-comment:this\n"
"str \042//\042 .d-line-comment:start\n"
"eat this\n"
"\n"
"state semicolon code\n"
"char \042 \134t\042 this\n"
"char -b a-zA-Z_ ident-label\n"
"noeat code\n"
"\n"
"state ident-label ident\n"
"char -b a-zA-Z0-9_ this\n"
"char -b : label\n"
"noeat -b ident\n"
"\n"
"state label\n"
"recolor label\n"
"noeat code\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist deprecated-keyword code error\n"
"inlist constant code\n"
"inlist type code\n"
"inlist special-token code\n"
"noeat code\n"
"\n"
"state ident-upper ident\n"
"char -b a-z class-name\n"
"char -b A-Z0-9_ ident\n"
"noeat code\n"
"\n"
"state class-name\n"
"recolor class-name\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state ident-upper-label ident\n"
"char -b a-z class-name-label\n"
"char -b A-Z0-9_ ident-label\n"
"char -b : label\n"
"noeat code\n"
"\n"
"state class-name-label class-name\n"
"char -b a-zA-Z0-9_ this\n"
"char -b : label\n"
"noeat -b class-name\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat code\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat code\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat code\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat code\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char fFlL float-suffix\n"
"char a-zA-Z0-9_ error-ident\n"
"noeat code\n"
"\n"
"state float-suffix numeric\n"
"char a-zA-Z0-9_ error-ident\n"
"noeat code\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"char a-zA-Z0-9_ error-ident\n"
"noeat code\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"char a-zA-Z0-9_ error-ident\n"
"noeat code\n"
"\n"
"state error-ident error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"list keyword \134\n"
"abstract alias align asm assert auto body break case cast catch \134\n"
"class const continue debug default deprecated do else enum export \134\n"
"extern final finally for foreach foreach_reverse goto if immutable \134\n"
"import in inout interface invariant is lazy macro mixin module new \134\n"
"nothrow out override package pragma private protected public pure \134\n"
"ref return scope shared static struct super switch synchronized \134\n"
"template this throw try typeid typeof union unittest version while \134\n"
"with __FILE__ __FILE_FULL_PATH__ __MODULE__ __LINE__ __FUNCTION__ \134\n"
"__PRETTY_FUNCTION__ __gshared __traits __vector __parameters\n"
"\n"
"list deprecated-keyword \134\n"
"delete typedef volatile\n"
"\n"
"list constant \134\n"
"true false null\n"
"\n"
"list type \134\n"
"bool byte ubyte short ushort int uint long ulong char wchar dchar \134\n"
"float double real ifloat idouble ireal cfloat cdouble creal void \134\n"
"cent ucent size_t ptrdiff_t function delegate\n"
"\n"
"list special-token \134\n"
"__DATE__ __EOF__ __TIME__ __TIMESTAMP__ __VENDOR__ __VERSION__\n"
"\n"
"default ident class-name\n"
"default macro special-token\n"
;

static CONFIG_SECTION const char builtin_syntax_diff[] =
"syntax diff\n"
"\n"
"state headers header\n"
"str 'diff ' header\n"
"str 'index ' header\n"
"str 'new ' header\n"
"str -- '--- ' header\n"
"str '+++ ' header\n"
"str '@@ ' chunk\n"
"char # comment\n"
"noeat text\n"
"\n"
"state header\n"
"char \042\134n\042 headers\n"
"eat this\n"
"\n"
"state chunk\n"
"char \042\134n\042 diff chunk\n"
"eat this\n"
"\n"
"state diff code\n"
"char ' ' context\n"
"char + added\n"
"char -- - removed\n"
"str '@@ ' chunk\n"
"noeat headers\n"
"\n"
"state context\n"
"char \042\134n\042 diff\n"
"eat this\n"
"\n"
"state added\n"
"char \042\134n\042 diff\n"
"eat this\n"
"\n"
"state removed\n"
"char \042\134n\042 diff\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 headers\n"
"eat this\n"
"\n"
"state text\n"
"char \042\134n\042 headers\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_docker[] =
"syntax docker\n"
"\n"
"list -i instruction \134\n"
"ADD CMD COPY ENTRYPOINT ENV EXPOSE FROM MAINTAINER ONBUILD RUN \134\n"
"USER VOLUME WORKDIR\n"
"\n"
"state start\n"
"char -b a-zA-Z ident\n"
"char # comment\n"
"char -n \042 \134t\134n\042 bad\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z this\n"
"char -bn \042 \134t\134n\042 bad error\n"
"inlist instruction arguments keyword\n"
"noeat -b bad\n"
"\n"
"state arguments\n"
"str \042\134\134\134n\042 this\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state bad error\n"
"recolor error\n"
"char \042 \134t\042 arguments\n"
"char \042\134n\042 start\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_dte[] =
"require c-uchar\n"
"\n"
"syntax dte\n"
"\n"
"state start code\n"
"char \042 \134t\042 this\n"
"char # comment\n"
"noeat command\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state command code\n"
"char \042'\042 sq\n"
"char '\042' dq\n"
"char \042\134n\042 start\n"
"char \042\134\134\042 escape\n"
"char -b \134$ variable\n"
"char \042;\042 this special\n"
"eat this\n"
"\n"
"state sq string\n"
"char \042'\042 command string\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state dq string\n"
"char \042\134\134\042 dq-escape\n"
"char '\042' command string\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state dq-escape special\n"
"char \042abefnrtv'\134\134\134\042\042 dq special\n"
"char x hex1\n"
"char u .c-uchar4:dq special\n"
"char U .c-uchar8:dq special\n"
"recolor error 1\n"
"char -n \042\134n\042 dq error\n"
"noeat dq\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"char '\042' command error\n"
"eat dq error\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F dq special\n"
"char '\042' command error\n"
"eat dq error\n"
"\n"
"state escape special\n"
"char \042\134n\042 command\n"
"eat command special\n"
"\n"
"state variable\n"
"char -b a-zA-Z_ this\n"
"noeat command\n"
;

static CONFIG_SECTION const char builtin_syntax_gcode[] =
"syntax gcode\n"
"\n"
"state code\n"
"char ';' comment\n"
"char ( paren-comment\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state paren-comment comment\n"
"char \042)\134n\042 code comment\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_gitcommit[] =
"syntax gitcommit\n"
"\n"
"state start text\n"
"char # comment-start\n"
"noeat text\n"
"\n"
"state text\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state comment-start comment\n"
"char \042\134n\042 start\n"
"char \042\134t\042 newfile comment\n"
"str ' On branch ' branch comment\n"
"str ' Changes to be committed:' comment added\n"
"str ' Changed but not updated:' comment modified\n"
"str ' Untracked files:' comment untracked\n"
"eat comment\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state branch notice\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state newfile\n"
"char \042\134n\042 start\n"
"char -bn : this\n"
"recolor label\n"
"noeat file\n"
"\n"
"state file\n"
"char \042\134n\042 start\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_gitignore[] =
"syntax gitignore\n"
"\n"
"state line-start text\n"
"char # comment\n"
"char ! text negated\n"
"noeat text\n"
"\n"
"state text\n"
"char \042\134n\042 line-start\n"
"char \042\134\134\042 backslash\n"
"char * this wildcard\n"
"char ? this matchone\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state backslash escape\n"
"char -n \042\134n\042 text escape\n"
"recolor error 1\n"
"eat line-start error\n"
"\n"
"default variable wildcard\n"
"default constant matchone\n"
"default label negated\n"
"default special escape\n"
;

static CONFIG_SECTION const char builtin_syntax_gitrebase[] =
"syntax gitrebase\n"
"\n"
"state start text\n"
"char \042\134n\042 this\n"
"char # comment\n"
"char -b a-zA-Z0-9_ word\n"
"eat error\n"
"\n"
"state word text\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword separator1\n"
"bufis x exec keyword\n"
"bufis exec exec keyword\n"
"noeat error\n"
"\n"
"state error\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state separator1 code\n"
"char \042 \134t\042 space1\n"
"noeat error\n"
"\n"
"state space1 code\n"
"char \042 \134t\042 this\n"
"noeat sha1\n"
"\n"
"state sha1 constant\n"
"char 0-9a-fA-F this\n"
"char \042\134n\042 start\n"
"char \042 \134t\042 title\n"
"noeat error\n"
"\n"
"state title text\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state exec code\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"list keyword \134\n"
"e f p r s edit fixup pick reword squash\n"
;

static CONFIG_SECTION const char builtin_syntax_go[] =
"syntax .go-esc\n"
"\n"
"state special\n"
"char 0-3 oct1\n"
"char 4-7 END error\n"
"char x 2left\n"
"char u 4left\n"
"char U 8left\n"
"noeat short\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat short\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat short\n"
"\n"
"state 8left special\n"
"char 0-9a-fA-F 7left\n"
"noeat short\n"
"\n"
"state 7left special\n"
"char 0-9a-fA-F 6left\n"
"noeat short\n"
"\n"
"state 6left special\n"
"char 0-9a-fA-F 5left\n"
"noeat short\n"
"\n"
"state 5left special\n"
"char 0-9a-fA-F 4left\n"
"noeat short\n"
"\n"
"state 4left special\n"
"char 0-9a-fA-F 3left\n"
"noeat short\n"
"\n"
"state 3left special\n"
"char 0-9a-fA-F 2left\n"
"noeat short\n"
"\n"
"state 2left special\n"
"char 0-9a-fA-F 1left\n"
"noeat short\n"
"\n"
"state 1left special\n"
"char 0-9a-fA-F END special\n"
"noeat short\n"
"\n"
"state short special\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state not-ascii error\n"
"char \042\134x80-\134xff\042 this\n"
"noeat END\n"
"\n"
"syntax go\n"
"\n"
"state go code\n"
"char -b A-Z exported\n"
"char -b a-z_ ident\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \042\134\042\042 string\n"
"char \042'\042 char\n"
"char ` raw-string\n"
"str \042//\042 cpp-comment\n"
"str \042/*\042 c-comment\n"
"eat this\n"
"\n"
"state exported\n"
"char -b a-zA-Z0-9_ this\n"
"noeat go\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword go\n"
"inlist type go\n"
"inlist constant go\n"
"inlist builtin go\n"
"noeat go\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat check-imag\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat check-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat check-imag\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat go\n"
"\n"
"state check-imag code\n"
"char i check-suffix numeric\n"
"noeat check-suffix\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat go\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"noeat check-imag\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"noeat check-imag\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"noeat check-imag\n"
"\n"
"state string\n"
"char \042\134\042\042 go string\n"
"char \042\134n\042 go\n"
"char \042\134\134\042 string-esc\n"
"eat this\n"
"\n"
"state string-esc special\n"
"char \042abfnrtv\134\042\134\134\042 string special\n"
"noeat .go-esc:string\n"
"\n"
"state char\n"
"char \042'\042 go error\n"
"char \042\134\134\042 char-esc\n"
"char \042\134n\042 go\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"eat char-end\n"
"\n"
"state char-esc special\n"
"char \042abfnrtv'\134\134\042 char-end special\n"
"noeat .go-esc:char-end\n"
"\n"
"state not-ascii char\n"
"char \042\134x80-\134xff\042 this\n"
"noeat char-end\n"
"\n"
"state char-end char\n"
"char \042'\042 go char\n"
"eat go error\n"
"\n"
"state raw-string string\n"
"char ` go string\n"
"eat this\n"
"\n"
"state cpp-comment comment\n"
"char \042\134n\042 go\n"
"eat this\n"
"\n"
"state c-comment comment\n"
"str \042*/\042 go comment\n"
"eat this\n"
"\n"
"list keyword \134\n"
"break case chan const continue default defer else fallthrough \134\n"
"for func go goto if import interface map package range return \134\n"
"select struct switch type var\n"
"\n"
"list constant \134\n"
"false true iota nil\n"
"\n"
"list builtin \134\n"
"append cap close complex delete copy imag len \134\n"
"make new panic print println real recover\n"
"\n"
"list type \134\n"
"bool byte complex64 complex128 float32 float64 \134\n"
"int8 int16 int32 int64 string uint8 uint16 uint32 uint64 \134\n"
"int uint uintptr error rune\n"
"\n"
"default ident exported\n"
;

static CONFIG_SECTION const char builtin_syntax_gomod[] =
"syntax gomod\n"
"\n"
"state code\n"
"char \134\042 dq-string\n"
"char ` raw-string\n"
"char / slash\n"
"char -bn \042 \134t\134r\134n\042 ident\n"
"eat this\n"
"\n"
"state ident\n"
"char -bn \042 \134t\134r\134n\134\042`/\042 this\n"
"inlist keyword code\n"
"bufis '=>' code arrow\n"
"noeat code\n"
"\n"
"state slash\n"
"char -n / ident\n"
"recolor comment 1\n"
"eat comment\n"
"\n"
"state comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state raw-string string\n"
"char \042`\134n\042 code\n"
"eat this\n"
"\n"
"state dq-string string\n"
"char \134\134 escape\n"
"char \134\042 code string\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state escape\n"
"eat dq-string escape\n"
"\n"
"list keyword \134\n"
"module go require replace exclude retract\n"
"\n"
"default special escape\n"
"default operator arrow\n"
;

static CONFIG_SECTION const char builtin_syntax_html[] =
"syntax .html-entity\n"
"\n"
"state entity\n"
"char # hash\n"
"char -b a-zA-Z name\n"
"recolor error 1\n"
"char \042\134n\042 END\n"
"eat END error\n"
"\n"
"state hash entity\n"
"char xX x\n"
"char 0-9 dec\n"
"eat END error\n"
"\n"
"state x entity\n"
"char 0-9a-fA-F hex\n"
"eat END error\n"
"\n"
"state hex entity\n"
"char 0-9a-fA-F this\n"
"char \042;\042 END entity\n"
"eat END error\n"
"\n"
"state dec entity\n"
"char 0-9 this\n"
"char \042;\042 END entity\n"
"eat END error\n"
"\n"
"state name entity\n"
"char -b a-zA-Z0-9 this\n"
"inlist entity optional-semicolon\n"
"noeat -b semicolon\n"
"\n"
"state optional-semicolon\n"
"char \042;\042 END entity\n"
"noeat END\n"
"\n"
"state semicolon\n"
"char \042;\042 END entity\n"
"recolor error\n"
"eat END error\n"
"\n"
"list entity \134\n"
"aacute Aacute acirc Acirc acute aelig AElig agrave Agrave amp AMP \134\n"
"aring Aring atilde Atilde auml Auml brvbar ccedil Ccedil cedil cent \134\n"
"copy COPY curren deg divide eacute Eacute ecirc Ecirc egrave Egrave \134\n"
"eth ETH euml Euml frac12 frac14 frac34 gt GT iacute Iacute icirc \134\n"
"Icirc iexcl igrave Igrave iquest iuml Iuml laquo lt LT macr micro \134\n"
"middot nbsp not ntilde Ntilde oacute Oacute ocirc Ocirc ograve \134\n"
"Ograve ordf ordm oslash Oslash otilde Otilde ouml Ouml para plusmn \134\n"
"pound quot QUOT raquo reg REG sect shy sup1 sup2 sup3 szlig thorn \134\n"
"THORN times uacute Uacute ucirc Ucirc ugrave Ugrave uml uuml Uuml \134\n"
"yacute Yacute yen yuml\n"
"\n"
"syntax html\n"
"\n"
"\n"
"state start text\n"
"char \042 \134t\134n\042 this\n"
"str \042<!\042 doctype\n"
"noeat text\n"
"\n"
"state doctype comment\n"
"char > text comment\n"
"char < text error\n"
"eat this\n"
"\n"
"state text\n"
"str \042<!--\042 comment\n"
"char < tag-start\n"
"char > start error\n"
"char \042&\042 .html-entity:this\n"
"eat this\n"
"\n"
"state comment\n"
"str -- --> text comment\n"
"eat this\n"
"\n"
"state tag-start tag\n"
"char / close-tag\n"
"char -b a-zA-Z0-9_ tag-name\n"
"char \042 \134t\134n\042 this\n"
"char > text tag\n"
"eat this error\n"
"\n"
"state close-tag tag\n"
"char -b a-zA-Z0-9_ close-tag-name\n"
"char \042 \134t\134n\042 this\n"
"eat text error\n"
"\n"
"state tag-name tag-unknown\n"
"char -b a-zA-Z0-9_ this\n"
"inlist tag attrs\n"
"inlist tag-deprecated attrs\n"
"noeat attrs\n"
"\n"
"state close-tag-name tag-unknown\n"
"char -b a-zA-Z0-9_ this\n"
"inlist tag close-tag-end\n"
"inlist tag-deprecated close-tag-end\n"
"noeat close-tag-end\n"
"\n"
"state close-tag-end tag\n"
"char \042 \134t\134n\042 this\n"
"char > text tag\n"
"eat text error\n"
"\n"
"state attrs code\n"
"char \042 \134t\134n\042 this\n"
"char -b a-zA-Z attr-name\n"
"char > text tag\n"
"char / short-close\n"
"eat this error\n"
"\n"
"state short-close tag\n"
"char > text tag\n"
"eat text error\n"
"\n"
"state attr-name attr\n"
"char a-zA-Z:_- this\n"
"char = attr-eq\n"
"noeat attrs\n"
"\n"
"state attr-eq attr\n"
"char \134\042 dq\n"
"char \134' sq\n"
"noeat attrs\n"
"\n"
"state dq string\n"
"char \134\042 attrs string\n"
"char \042\134n\042 attrs\n"
"char \042&\042 .html-entity:this\n"
"eat this\n"
"\n"
"state sq string\n"
"char \134' attrs string\n"
"char \042\134n\042 attrs\n"
"char \042&\042 .html-entity:this\n"
"eat this\n"
"\n"
"list -i tag \134\n"
"a abbr address area b base bdo blockquote body br \134\n"
"button caption cite code col colgroup dd del dfn div dl dt em \134\n"
"fieldset form h1 h2 h3 h4 h5 h6 head hr html i iframe img input \134\n"
"ins kbd label legend li link map meta noscript object ol optgroup \134\n"
"option p param pre q samp script select small span strong style \134\n"
"sub sup table tbody td textarea tfoot th thead title tr ul var \134\n"
"\134\n"
"article aside audio bdi canvas command data datalist details \134\n"
"dialog embed figcaption figure footer header hgroup main mark \134\n"
"menu meter nav output picture progress rp rt ruby s section slot \134\n"
"source summary template time track u video wbr\n"
"\n"
"list -i tag-deprecated \134\n"
"acronym applet basefont bgsound big blink center dir font frame \134\n"
"frameset isindex keygen listing marquee menuitem multicol \134\n"
"nextid nobr noembed noframes plaintext rb rtc spacer strike tt \134\n"
"xmp\n"
"\n"
"default code tag-unknown\n"
"default error tag-deprecated\n"
"default special entity\n"
;

static CONFIG_SECTION const char builtin_syntax_ini[] =
"syntax .ini-comment\n"
"\n"
"state maybe-comment text\n"
"char -b \042 \134t\042 this\n"
"char '#;' comment\n"
"noeat -b END\n"
"\n"
"state comment\n"
"char -n \042\134n\042 this\n"
"noeat END\n"
"\n"
"syntax ini\n"
"\n"
"\n"
"state line-start\n"
"char \042 \134t\134n\042 this\n"
"char [ section\n"
"char '#;' comment\n"
"char = value error\n"
"noeat text\n"
"\n"
"state section ini.section\n"
"char ] section-end ini.section\n"
"char \042\134n\042 line-start error\n"
"eat this\n"
"\n"
"state section-end\n"
"char \042 \134t\042 .ini-comment:this\n"
"char \042\134n\042 line-start\n"
"eat this error\n"
"\n"
"state text\n"
"char -b \042 \134t\042 .ini-comment:this\n"
"char -b = key operator\n"
"char -bn \042\134n\042 this\n"
"noeat line-start\n"
"\n"
"state key\n"
"recolor variable\n"
"recolor operator 1\n"
"noeat value\n"
"\n"
"state value\n"
"char \134' single-quote\n"
"char \134\042 double-quote\n"
"char -b a-z this\n"
"inlist constant this constant\n"
"char \042 \134t\042 .ini-comment:this\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state single-quote string\n"
"char \134' value string\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state double-quote string\n"
"char \134\042 value string\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"list constant true false\n"
;

static CONFIG_SECTION const char builtin_syntax_java[] =
"syntax .java-esc\n"
"\n"
"state char-esc special\n"
"char \042bfnrt\134\134'\134\042\042 END special\n"
"char 0 oct\n"
"char u hex4\n"
"noeat short\n"
"\n"
"state oct special\n"
"char 0-3 oct2\n"
"char 4-7 oct1\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 oct1\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex4 special\n"
"char 0-9a-fA-F hex3\n"
"noeat END\n"
"\n"
"state hex3 special\n"
"char 0-9a-fA-F hex2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F END special\n"
"noeat END\n"
"\n"
"state short special\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state not-ascii error\n"
"char \042\134x80-\134xff\042 this\n"
"noeat END\n"
"\n"
"syntax java\n"
"\n"
"state code\n"
"char -b a-zA-Z_ ident\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \134\042 string\n"
"char \134' char\n"
"str \042//\042 cpp-comment\n"
"str \042/*\042 c-comment\n"
"eat this\n"
"\n"
"state cpp-comment comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state c-comment comment\n"
"str \042*/\042 code comment\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist type code\n"
"inlist constant code\n"
"noeat code\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat num-suffix\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat num-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat num-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat num-suffix\n"
"\n"
"state num-suffix\n"
"char lLfFdD check-suffix numeric\n"
"noeat check-suffix\n"
"\n"
"state float-suffix\n"
"char fFdD check-suffix numeric\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"noeat float-suffix\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"noeat float-suffix\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"noeat float-suffix\n"
"\n"
"state string\n"
"char \134\134 .java-esc:this\n"
"char \134\042 code string\n"
"eat this\n"
"\n"
"state char\n"
"char \042\134\134\042 .java-esc:char-end\n"
"char \042\134n\042 code\n"
"char \134' code error\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"eat char-end\n"
"\n"
"state not-ascii char\n"
"char \042\134x80-\134xff\042 this\n"
"noeat char-end\n"
"\n"
"state char-end char\n"
"char \134' code char\n"
"eat code error\n"
"\n"
"list keyword \134\n"
"abstract assert boolean break byte case catch char class const \134\n"
"continue default do double else enum extends final finally float \134\n"
"for goto if implements import instanceof int interface long native \134\n"
"new package private protected public return short static strictfp \134\n"
"super switch synchronized this throw throws transient try void \134\n"
"volatile while\n"
"\n"
"list type \134\n"
"byte short int long float double boolean char\n"
"\n"
"list constant \134\n"
"false true null\n"
;

static CONFIG_SECTION const char builtin_syntax_javascript[] =
"syntax .js-esc\n"
"\n"
"state special\n"
"char \042'\134\042`\134\134bfnrtv\042 END special\n"
"char 0 3n\n"
"char x 2left\n"
"char u 4left\n"
"noeat short\n"
"\n"
"state 4left special\n"
"char 0-9a-fA-F 3left\n"
"noeat short\n"
"\n"
"state 3left special\n"
"char 0-9a-fA-F 2left\n"
"noeat short\n"
"\n"
"state 2left special\n"
"char 0-9a-fA-F 1left\n"
"noeat short\n"
"\n"
"state 1left special\n"
"char 0-9a-fA-F END special\n"
"noeat short\n"
"\n"
"state 3n special\n"
"char 0-9 2n\n"
"noeat short\n"
"\n"
"state 2n special\n"
"char 0-9 1n\n"
"noeat short\n"
"\n"
"state 1n special\n"
"char 0-9 END special\n"
"noeat short\n"
"\n"
"state short special\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"syntax .js-regexp\n"
"\n"
"state regexp\n"
"char \042\134\134\042 regexp-esc\n"
"char \042[\042 regexp-char-list-start\n"
"char \042{\042 regexp-range\n"
"char \042/\042 regexp-flags regexp\n"
"char \042^$|()?:*+.\042 this regexp-special\n"
"char \042\134n\042 END error\n"
"eat this\n"
"\n"
"state regexp-esc regexp-special\n"
"char \042\134n\042 END error\n"
"eat regexp regexp-special\n"
"\n"
"state regexp-char-list-start regexp-special\n"
"char ^ regexp-char-list regexp-special\n"
"char ] regexp regexp-special\n"
"char \042\134n\042 END error\n"
"eat regexp-char-list\n"
"\n"
"state regexp-char-list regexp\n"
"char \042-\042 this regexp-special\n"
"char \042\134\134\042 regexp-char-list-esc\n"
"char ] regexp regexp-special\n"
"char \042\134n\042 END error\n"
"eat this\n"
"\n"
"state regexp-char-list-esc regexp-special\n"
"char \042\134n\042 END error\n"
"eat regexp-char-list regexp-special\n"
"\n"
"state regexp-range regexp-special\n"
"char \0420-9\042 this regexp\n"
"char \042,\042 regexp-range-second\n"
"char \042}\042 regexp regexp-special\n"
"char \042\134n\042 END error\n"
"eat this error\n"
"\n"
"state regexp-range-second regexp-special\n"
"char \0420-9\042 this regexp\n"
"char \042}\042 regexp regexp-special\n"
"char \042\134n\042 END error\n"
"eat this error\n"
"\n"
"state regexp-flags regexp-special\n"
"char gimuy this\n"
"noeat END\n"
"\n"
"syntax javascript\n"
"\n"
"state first-line\n"
"char \042 \134t\042 this\n"
"char # line-comment\n"
"noeat code\n"
"\n"
"state code\n"
"char -b a-zA-Z_ ident\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"str \042//\042 line-comment\n"
"str \042/*\042 long-comment\n"
"char \134' sq\n"
"char \134\042 dq\n"
"char ` bt\n"
"char \042(;:,=*/%&|!?+-\042 foo\n"
"eat this\n"
"\n"
"state foo code\n"
"char \042 \134t(;:,=*%&|!?+-\042 this\n"
"str \042//\042 line-comment\n"
"str \042/*\042 long-comment\n"
"char / .js-regexp:code\n"
"noeat code\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat check-suffix\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"noeat check-suffix\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"noeat check-suffix\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist reserved code keyword\n"
"inlist type code\n"
"inlist errortype code type\n"
"inlist constant code\n"
"inlist builtin-namespace code constant\n"
"inlist function code builtin\n"
"inlist message code builtin\n"
"inlist global code builtin\n"
"inlist member code builtin\n"
"inlist deprecated code\n"
"noeat code\n"
"\n"
"state line-comment comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state long-comment comment\n"
"str \042*/\042 code comment\n"
"eat this\n"
"\n"
"state sq string\n"
"char \134' code string\n"
"char \042\134n\042 code\n"
"char \042\134\134\042 .js-esc:this\n"
"eat this\n"
"\n"
"state dq string\n"
"char \134\042 code string\n"
"char \042\134n\042 code\n"
"char \042\134\134\042 .js-esc:this\n"
"eat this\n"
"\n"
"state bt string\n"
"char ` code string\n"
"char \042\134\134\042 .js-esc:this\n"
"eat this\n"
"\n"
"list keyword \134\n"
"break case catch continue debugger default delete do else finally for \134\n"
"function if in instanceof new return switch this throw try typeof var \134\n"
"void while with\n"
"\n"
"list reserved \134\n"
"class const enum export extends implements import interface let \134\n"
"package private protected public static super yield\n"
"\n"
"list type \134\n"
"Array Boolean Date Function Number Object RegExp String \134\n"
"Map WeakMap Set WeakSet Symbol Promise Proxy ArrayBuffer DataView \134\n"
"Float32Array Float64Array Int8Array Int16Array Int32Array \134\n"
"Uint8Array Uint16Array Uint32Array Uint8ClampedArray\n"
"\n"
"list builtin-namespace \134\n"
"Intl JSON Math Reflect WebAssembly\n"
"\n"
"list errortype \134\n"
"Error EvalError RangeError ReferenceError SyntaxError TypeError URIError\n"
"\n"
"list constant \134\n"
"arguments \134\n"
"Infinity NaN false null true undefined\n"
"\n"
"list function \134\n"
"decodeURI decodeURIComponent encodeURI encodeURIComponent eval \134\n"
"isFinite isNaN parseFloat parseInt\n"
"\n"
"list message \134\n"
"alert confirm prompt status\n"
"\n"
"list global \134\n"
"self window top parent\n"
"\n"
"list member \134\n"
"document event location\n"
"\n"
"list deprecated \134\n"
"escape unescape\n"
"\n"
"default special regexp\n"
"default special regexp-special\n"
;

static CONFIG_SECTION const char builtin_syntax_json[] =
"require c-uchar\n"
"\n"
"syntax json\n"
"\n"
"state value code\n"
"char -b a-zA-Z_ ident\n"
"char \134\042 string\n"
"char 0 zero\n"
"char 1-9 number\n"
"eat this\n"
"\n"
"state ident code\n"
"char -b a-zA-Z0-9_ this\n"
"inlist constant this\n"
"noeat value\n"
"\n"
"state string\n"
"char \134\042 value string\n"
"char \134\134 string-escape\n"
"char \042\134n\042 value\n"
"eat this\n"
"\n"
"state string-escape special\n"
"char \134\042\134\134/bfnrt string special\n"
"char u .c-uchar4:string special\n"
"eat string error\n"
"\n"
"state zero numeric\n"
"char . fraction\n"
"char eE exponent\n"
"noeat check-num-suffix\n"
"\n"
"state number numeric\n"
"char 0-9 this\n"
"char . fraction\n"
"char eE exponent\n"
"noeat check-num-suffix\n"
"\n"
"state fraction numeric\n"
"char 0-9 this\n"
"char eE exponent\n"
"noeat check-num-suffix\n"
"\n"
"state exponent numeric\n"
"char +- exponent-signed\n"
"char -b 0-9 this\n"
"noeat check-num-suffix\n"
"\n"
"state exponent-signed numeric\n"
"char 0-9 this\n"
"noeat check-num-suffix\n"
"\n"
"state check-num-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat value\n"
"\n"
"list constant true false null\n"
;

static CONFIG_SECTION const char builtin_syntax_lisp[] =
"syntax lisp\n"
"\n"
"state start code\n"
"char \042;\042 comment\n"
"char '\042' string\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state string\n"
"char \042\134\042\042 start string\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_lua[] =
"syntax .lua-long-string\n"
"\n"
"state body string\n"
"char ] end-match\n"
"eat this\n"
"\n"
"state end-match string\n"
"heredocend end\n"
"noeat body\n"
"\n"
"state end string\n"
"char ] END string\n"
"noeat body\n"
"\n"
"syntax .lua-long-comment\n"
"\n"
"state body comment\n"
"char ] end-match\n"
"eat this\n"
"\n"
"state end-match comment\n"
"heredocend end\n"
"noeat body\n"
"\n"
"state end comment\n"
"char ] END comment\n"
"noeat body\n"
"\n"
"syntax .lua-escape\n"
"\n"
"state escape\n"
"char \042abfnrtv\134\134\134\042'\042 END special\n"
"char x hex1\n"
"char 0-1 decimal-low\n"
"char 2 decimal-two\n"
"char 3-9 decimal-high\n"
"noeat short\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F hex2\n"
"noeat short\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F END special\n"
"noeat short\n"
"\n"
"state decimal-low special\n"
"char 0-9 decimal-last\n"
"noeat END\n"
"\n"
"state decimal-last special\n"
"char 0-9 END special\n"
"noeat END\n"
"\n"
"state decimal-two special\n"
"char 0-4 decimal-last\n"
"char 5 decimal-two-five\n"
"char 6-9 decimal-short\n"
"noeat END\n"
"\n"
"state decimal-two-five special\n"
"char 0-5 END special\n"
"char 6-9 END error\n"
"noeat END\n"
"\n"
"state decimal-high special\n"
"char 0-9 decimal-short\n"
"noeat END\n"
"\n"
"state decimal-short special\n"
"char 0-9 END error\n"
"noeat END\n"
"\n"
"state short special\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"syntax lua\n"
"\n"
"list constant false true nil\n"
"list opword and or not\n"
"\n"
"list keyword \134\n"
"do end while repeat until if elseif then else for in \134\n"
"function local return goto break\n"
"\n"
"state first-line\n"
"char \042 \134t\042 this\n"
"char # line-comment\n"
"noeat code\n"
"\n"
"state code\n"
"char -b a-zA-Z_ identifier\n"
"char 0 zero\n"
"char 1-9 decimal\n"
"char \134' single-quote\n"
"char \134\042 double-quote\n"
"char \134- dash\n"
"char [ bracket\n"
"char -b : colon\n"
"str '~=' this operator\n"
"char =/+*#<>^%|&~ this operator\n"
"str '...' this special\n"
"str '..' this operator\n"
"char . dot\n"
"char '!@`$?' this error\n"
"eat this\n"
"\n"
"state bracket string\n"
"char [ .lua-long-string:code string\n"
"char -b = bracket-equals\n"
"recolor default 1\n"
"noeat code\n"
"\n"
"state colon\n"
"char -b : colon-colon\n"
"noeat code\n"
"\n"
"state colon-colon\n"
"char -b a-zA-Z_ colon-colon-name\n"
"eat code error\n"
"\n"
"state colon-colon-name\n"
"char -b a-zA-Z0-9_ this\n"
"char -b : colon-colon-name-colon\n"
"eat code error\n"
"\n"
"state colon-colon-name-colon\n"
"char -b : label\n"
"eat code error\n"
"\n"
"state label\n"
"recolor label\n"
"noeat code\n"
"\n"
"state bracket-equals string\n"
"char -b = this\n"
"char -n [ code error\n"
"heredocbegin .lua-long-string code\n"
"\n"
"state dash operator\n"
"char \134- dash-dash\n"
"noeat code\n"
"\n"
"state dash-dash comment\n"
"recolor comment 2\n"
"char \042\134n\042 code\n"
"char [ dash-dash-bracket\n"
"eat line-comment comment\n"
"\n"
"state dash-dash-bracket comment\n"
"char [ .lua-long-comment:code comment\n"
"char -b = dash-dash-bracket-equals comment\n"
"eat line-comment\n"
"\n"
"state dash-dash-bracket-equals\n"
"char -b = this comment\n"
"char -n [ line-comment\n"
"heredocbegin .lua-long-comment code\n"
"\n"
"state line-comment comment\n"
"char \042\134n\042 code\n"
"eat this comment\n"
"\n"
"state zero numeric\n"
"char 0-9 decimal\n"
"char xX hex\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state decimal numeric\n"
"char 0-9 this\n"
"char eE exponent\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat check-suffix\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exponent\n"
"noeat check-suffix\n"
"\n"
"state exponent numeric\n"
"char +- exponent-digit\n"
"char 0-9 exponent-digit\n"
"noeat check-suffix\n"
"\n"
"state exponent-digit numeric\n"
"char 0-9 this\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state dot\n"
"char 0-9 dot-float\n"
"noeat code\n"
"\n"
"state dot-float\n"
"recolor numeric 2\n"
"noeat float\n"
"\n"
"state identifier\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist constant code\n"
"inlist opword code operator\n"
"noeat code\n"
"\n"
"state single-quote string\n"
"char \134' code string\n"
"char \042\134n\042 code\n"
"char \042\134\134\042 .lua-escape:this special\n"
"eat this\n"
"\n"
"state double-quote string\n"
"char \134\042 code string\n"
"char \042\134n\042 code\n"
"char \042\134\134\042 .lua-escape:this special\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_mail[] =
"syntax mail\n"
"\n"
"state bol text\n"
"char '>' quote\n"
"noeat text\n"
"\n"
"state text\n"
"char \042\134n\042 bol\n"
"eat this\n"
"\n"
"state quote\n"
"char \042\134n\042 bol\n"
"eat this\n"
"\n"
"default comment quote\n"
;

static CONFIG_SECTION const char builtin_syntax_make[] =
"syntax make\n"
"\n"
"state start code\n"
"char \042\134n\042 this\n"
"char \042\134t\042 tab-indent\n"
"char ' '  space-indent\n"
"noeat not-recipe\n"
"\n"
"state tab-indent code\n"
"char \042 \134t\042 this\n"
"char \042\134n\042 start\n"
"char -b a-zA-Z_- not-target\n"
"noeat make\n"
"\n"
"state space-indent code\n"
"char \042 \134t\042 this\n"
"noeat not-recipe\n"
"\n"
"state not-target code\n"
"char -b a-zA-Z_- this\n"
"inlist keyword make\n"
"noeat make\n"
"\n"
"state not-recipe code\n"
"char -b . special-target\n"
"char -b a-zA-Z_- this\n"
"inlist keyword make\n"
"noeat make\n"
"\n"
"state special-target code\n"
"char -b A-Z_ this\n"
"inlist special-target make\n"
"noeat make\n"
"\n"
"state make code\n"
"char # comment\n"
"char \134$ dollar\n"
"char \042\134n\042 start\n"
"char \134\134 esc\n"
"char ')}' this variable\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"char \134\134 comment-esc\n"
"eat this\n"
"\n"
"state comment-esc comment\n"
"char \042\134\134\134n\042 comment\n"
"noeat comment\n"
"\n"
"state dollar variable\n"
"char '({' lp\n"
"char a-zA-Z make variable\n"
"char '@%<?^+|*' make variable\n"
"char \134$ make variable\n"
"noeat make\n"
"\n"
"state lp variable\n"
"char -b a-zA-Z0-9_- variable\n"
"noeat make\n"
"\n"
"state variable\n"
"char -b a-zA-Z0-9_- this\n"
"char ')}' make variable\n"
"inlist function make builtin\n"
"noeat make\n"
"\n"
"state esc special\n"
"char \042\134n\042 make\n"
"eat make special\n"
"\n"
"list keyword -- \134\n"
"define else endef endif export ifdef ifeq ifndef ifneq -include \134\n"
"include override unexport vpath\n"
"\n"
"list function \134\n"
"abspath addprefix addsuffix and basename bindir call dir error eval \134\n"
"filter filter-out findstring firstword flavor foreach if info join \134\n"
"lastword notdir or origin patsubst realpath shell sort strip subst \134\n"
"suffix value warning wildcard word wordlist words\n"
"\n"
"list special-target \134\n"
".DEFAULT .DEFAULT_GOAL .DELETE_ON_ERROR .EXPORT_ALL_VARIABLES \134\n"
".FEATURES .IGNORE .INCLUDE_DIRS .INTERMEDIATE .LIBPATTERNS \134\n"
".LOW_RESOLUTION_TIME .NOTPARALLEL .ONESHELL .PHONY .POSIX .PRECIOUS \134\n"
".SECONDARY .SECONDEXPANSION .SILENT .SUFFIXES .VARIABLES\n"
"\n"
"default constant special-target\n"
;

static CONFIG_SECTION const char builtin_syntax_markdown[] =
"syntax .markdown-escape\n"
"\n"
"state char special\n"
"char !-/:-@[-`{-~ END special\n"
"recolor text 1\n"
"noeat END\n"
"\n"
"syntax .markdown-fenced-code-block\n"
"\n"
"state body code-block\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state line-start code-block\n"
"heredocend end\n"
"noeat body\n"
"\n"
"state end code-block\n"
"char \042\134n\042 END\n"
"noeat body\n"
"\n"
"syntax markdown\n"
"\n"
"\n"
"state file-start\n"
"str -- \042---\134n\042 yaml\n"
"noeat line-start\n"
"\n"
"state yaml\n"
"str -- \042---\134n\042 line-start yaml\n"
"str \042...\134n\042 line-start yaml\n"
"eat this\n"
"\n"
"state line-start\n"
"char \042\134n\042 block-start\n"
"char \042 \042 this\n"
"char # hash-heading\n"
"char > block-quote\n"
"char [ maybe-link-def\n"
"char -b 0-9 digit\n"
"str \042**\042 double-asterisk\n"
"str '__' double-underscore\n"
"char * bullet-asterisk emphasis\n"
"char _ underscore\n"
"char +- bullet\n"
"char -b \042~\042 tilde\n"
"char -b \042`\042 backtick\n"
"noeat text\n"
"\n"
"state block-start\n"
"str \042    \042 code-block\n"
"char \042\134t\042 code-block\n"
"char \042\134n \042 this\n"
"noeat line-start\n"
"\n"
"state text\n"
"char \042\134n\042 line-start\n"
"char \042 \134t\042 space\n"
"char '`' code-span\n"
"char [ reference\n"
"str '**' double-asterisk\n"
"char * asterisk\n"
"char \042\134\134\042 .markdown-escape:this\n"
"eat this\n"
"\n"
"state space\n"
"char \042 \134t\042 this\n"
"str '__' double-underscore\n"
"char _ underscore\n"
"noeat text\n"
"\n"
"state bullet\n"
"char \042\134n\042 line-start\n"
"char -n \042 \134t\042 text\n"
"recolor unordered-list 2\n"
"noeat text\n"
"\n"
"state bullet-asterisk\n"
"char \042\134n\042 line-start\n"
"char -n \042 \134t\042 asterisk emphasis\n"
"recolor unordered-list 2\n"
"noeat text\n"
"\n"
"state code-block\n"
"char \042\134n\042 block-start\n"
"eat this\n"
"\n"
"state backtick code-block\n"
"char -b '`' this\n"
"bufis '`' code-span\n"
"bufis '``' text code-span\n"
"heredocbegin .markdown-fenced-code-block line-start\n"
"\n"
"state tilde code-block\n"
"char -b '~' this\n"
"bufis '~' text\n"
"bufis '~~' text\n"
"heredocbegin .markdown-fenced-code-block line-start\n"
"\n"
"state block-quote\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state digit\n"
"char \042\134n\042 line-start\n"
"char -b 0-9 this\n"
"char -n . text\n"
"recolor ordered-list\n"
"eat text ordered-list\n"
"\n"
"state hash-heading heading\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state code-span\n"
"char \042\134n\042 line-start\n"
"char ` text code-span\n"
"eat this\n"
"\n"
"state asterisk emphasis\n"
"char * text emphasis\n"
"char -n \042\134n\042 this\n"
"noeat line-start\n"
"\n"
"state double-asterisk strong-emphasis\n"
"char \042\134n\042 line-start\n"
"str '**' text strong-emphasis\n"
"eat this\n"
"\n"
"state underscore emphasis\n"
"char _ text emphasis\n"
"char -n \042\134n\042 this\n"
"noeat line-start\n"
"\n"
"state double-underscore strong-emphasis\n"
"char \042\134n\042 line-start\n"
"str '__' text strong-emphasis\n"
"eat this\n"
"\n"
"state reference\n"
"char \042\134\134\042 .markdown-escape:this\n"
"char ] reference-close reference\n"
"eat this\n"
"\n"
"state reference-close\n"
"char \042\134n\042 line-start\n"
"noeat text\n"
"\n"
"state maybe-link-def reference\n"
"char \042\134\134\042 .markdown-escape:this\n"
"char ] maybe-link-def-close\n"
"eat this\n"
"\n"
"state maybe-link-def-close reference\n"
"char : link-def reference\n"
"noeat reference-close\n"
"\n"
"state link-def\n"
"char \042 \134t\042 this\n"
"char \042\134n\042 line-start\n"
"noeat link-def-url\n"
"\n"
"state link-def-url url\n"
"char \042\134n\042 line-start\n"
"char \042 \134t\042 link-def-after-url\n"
"eat this\n"
"\n"
"state link-def-after-url text\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"default comment yaml\n"
"default special unordered-list\n"
"default numeric ordered-list\n"
;

static CONFIG_SECTION const char builtin_syntax_meson[] =
"syntax meson\n"
"\n"
"list keyword if elif else endif foreach endforeach\n"
"list constant true false\n"
"\n"
"state start code\n"
"char # comment\n"
"str \042'''\042 longstring\n"
"char \042'\042 string\n"
"char -b a-zA-Z_ ident\n"
"char 0-9 number\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state longstring string\n"
"str \042'''\042 start string\n"
"eat this\n"
"\n"
"state string string\n"
"char \042'\042 start string\n"
"char \042\134n\042 start\n"
"char -b \042\134\134\042 string-escape\n"
"eat this\n"
"\n"
"state string-escape special\n"
"char \042n'\134\134\042 string special\n"
"recolor string\n"
"noeat string\n"
"\n"
"state ident\n"
"char -b a-zA-Z_0-9 this\n"
"inlist keyword start\n"
"inlist constant start\n"
"noeat start\n"
"\n"
"state number numeric\n"
"char 0-9 this\n"
"noeat start\n"
;

static CONFIG_SECTION const char builtin_syntax_nginx[] =
"syntax .nginx-var\n"
"\n"
"state variable\n"
"char '{' brace\n"
"char A-Za-z0-9_ this\n"
"noeat END\n"
"\n"
"state brace variable\n"
"char A-Za-z0-9_ this\n"
"char '}' END variable\n"
"eat END error\n"
"\n"
"syntax .nginx-sq-string\n"
"\n"
"state string\n"
"char \042\134\134\042 escape\n"
"char \134$ .nginx-var:this\n"
"char \042'\042 END string\n"
"eat this\n"
"\n"
"state escape special\n"
"char \042'$\042 string special\n"
"eat string error\n"
"\n"
"syntax .nginx-dq-string\n"
"\n"
"state string\n"
"char \042\134\134\042 escape\n"
"char \134$ .nginx-var:this\n"
"char \042\134\042\042 END string\n"
"eat this\n"
"\n"
"state escape special\n"
"char \042\134\042$\042 string special\n"
"eat string error\n"
"\n"
"syntax nginx\n"
"\n"
"state line-start\n"
"char -b a-z_ first-word\n"
"char \042;\134n\134t \042 this\n"
"noeat nginx\n"
"\n"
"state nginx\n"
"char \134$ .nginx-var:this\n"
"char \042\134\042\042 .nginx-dq-string:this\n"
"char \042'\042 .nginx-sq-string:this\n"
"char \134\134 escape\n"
"char # comment\n"
"char \042;\134n{\042 line-start\n"
"eat this\n"
"\n"
"state first-word\n"
"char -b a-z_ this\n"
"inlist directive nginx keyword\n"
"inlist deprecated_directive nginx error\n"
"noeat nginx\n"
"\n"
"state escape special\n"
"char \042\134\042\134\134'trn.$\042 nginx special\n"
"recolor error 1\n"
"noeat nginx\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"list directive \134\n"
"accept_mutex accept_mutex_delay access_log add_after_body \134\n"
"add_before_body add_header addition_types aio alias allow \134\n"
"ancient_browser ancient_browser_value auth_basic \134\n"
"auth_basic_user_file auth_http auth_http_header auth_http_timeout \134\n"
"auth_request auth_request_set autoindex autoindex_exact_size \134\n"
"autoindex_localtime break charset charset_map charset_types \134\n"
"chunked_transfer_encoding client_body_buffer_size \134\n"
"client_body_in_file_only client_body_in_single_buffer \134\n"
"client_body_temp_path client_body_timeout client_header_buffer_size \134\n"
"client_header_timeout client_max_body_size connection_pool_size \134\n"
"create_full_put_path daemon dav_access dav_methods debug_connection \134\n"
"debug_points default_type deny directio directio_alignment \134\n"
"disable_symlinks empty_gif env error_log error_page etag events \134\n"
"expires f fastcgi_bind fastcgi_buffering fastcgi_buffers \134\n"
"fastcgi_buffer_size fastcgi_busy_buffers_size fastcgi_cache \134\n"
"fastcgi_cache_bypass fastcgi_cache_key fastcgi_cache_lock \134\n"
"fastcgi_cache_lock_timeout fastcgi_cache_methods \134\n"
"fastcgi_cache_min_uses fastcgi_cache_path fastcgi_cache_purge \134\n"
"fastcgi_cache_revalidate fastcgi_cache_use_stale fastcgi_cache_valid \134\n"
"fastcgi_catch_stderr fastcgi_connect_timeout fastcgi_hide_header \134\n"
"fastcgi_ignore_client_abort fastcgi_ignore_headers fastcgi_index \134\n"
"fastcgi_intercept_errors fastcgi_keep_conn \134\n"
"fastcgi_max_temp_file_size fastcgi_next_upstream \134\n"
"fastcgi_next_upstream_timeout fastcgi_next_upstream_tries \134\n"
"fastcgi_no_cache fastcgi_param fastcgi_pass fastcgi_pass_header \134\n"
"fastcgi_pass_request_body fastcgi_pass_request_headers \134\n"
"fastcgi_read_timeout fastcgi_send_lowat fastcgi_send_timeout \134\n"
"fastcgi_split_path_info fastcgi_store fastcgi_store_access \134\n"
"fastcgi_temp_file_write_size fastcgi_temp_path flv geo geoip_city \134\n"
"geoip_country geoip_org geoip_proxy geoip_proxy_recursive gunzip \134\n"
"gunzip_buffers gzip gzip_buffers gzip_comp_level gzip_disable \134\n"
"gzip_http_version gzip_min_length gzip_proxied gzip_static \134\n"
"gzip_types gzip_vary hash health_check hls hls_buffers \134\n"
"hls_forward_args hls_fragment hls_mp http if if_modified_since \134\n"
"ignore_invalid_headers image_filter image_filter_buffer \134\n"
"image_filter_interlace image_filter_jpeg_quality \134\n"
"image_filter_sharpen image_filter_transparency imap_auth \134\n"
"imap_capabilities imap_client_buffer include index internal ip_hash \134\n"
"keepalive keepalive_disable keepalive_requests keepalive_timeout \134\n"
"large_client_header_buffers least_conn limit_conn \134\n"
"limit_conn_log_level limit_conn_status limit_conn_zone limit_except \134\n"
"limit_rate limit_rate_after limit_req limit_req_log_level \134\n"
"limit_req_status limit_req_zone limit_zone lingering_close \134\n"
"lingering_time lingering_timeout listen location lock_file \134\n"
"log_format log_not_found log_subrequest mail map \134\n"
"map_hash_bucket_size map_hash_max_size master_process match \134\n"
"max_ranges memcached_bind memcached_buffer_size \134\n"
"memcached_connect_timeout memcached_gzip_flag \134\n"
"memcached_next_upstream memcached_next_upstream_timeout \134\n"
"memcached_next_upstream_tries memcached_pass memcached_read_timeout \134\n"
"memcached_send_timeout merge_slashes min_delete_depth modern_browser \134\n"
"modern_browser_value mp msie_padding msie_refresh multi_accept \134\n"
"open_file_cache open_file_cache_errors open_file_cache_min_uses \134\n"
"open_file_cache_valid open_log_file_cache \134\n"
"output_buffers override_charset pcre_jit perl perl_modules \134\n"
"perl_require perl_set pid pop port_in_redirect postpone_output \134\n"
"protocol proxy_bind proxy_buffer proxy_buffering proxy_buffers \134\n"
"proxy_buffer_size proxy_busy_buffers_size proxy_cache \134\n"
"proxy_cache_bypass proxy_cache_key proxy_cache_lock \134\n"
"proxy_cache_lock_timeout proxy_cache_methods proxy_cache_min_uses \134\n"
"proxy_cache_path proxy_cache_purge proxy_cache_revalidate \134\n"
"proxy_cache_use_stale proxy_cache_valid proxy_connect_timeout \134\n"
"proxy_cookie_domain proxy_cookie_path proxy_headers_hash_bucket_size \134\n"
"proxy_headers_hash_max_size proxy_hide_header proxy_http_version \134\n"
"proxy_ignore_client_abort proxy_ignore_headers \134\n"
"proxy_intercept_errors proxy_max_temp_file_size proxy_method \134\n"
"proxy_next_upstream proxy_next_upstream_timeout \134\n"
"proxy_next_upstream_tries proxy_no_cache proxy_pass \134\n"
"proxy_pass_error_message proxy_pass_header proxy_pass_request_body \134\n"
"proxy_pass_request_headers proxy_read_timeout proxy_redirect \134\n"
"proxy_send_lowat proxy_send_timeout proxy_set_body proxy_set_header \134\n"
"proxy_ssl_ciphers proxy_ssl_crl proxy_ssl_name proxy_ssl_protocols \134\n"
"proxy_ssl_server_name proxy_ssl_session_reuse \134\n"
"proxy_ssl_trusted_certificate proxy_ssl_verify \134\n"
"proxy_ssl_verify_depth proxy_store proxy_store_access \134\n"
"proxy_temp_file_write_size proxy_temp_path proxy_timeout queue \134\n"
"random_index read_ahead real_ip_header real_ip_recursive \134\n"
"recursive_error_pages referer_hash_bucket_size referer_hash_max_size \134\n"
"request_pool_size reset_timedout_connection resolver \134\n"
"resolver_timeout return rewrite rewrite_log root satisfy \134\n"
"scgi_bind scgi_buffering scgi_buffers scgi_buffer_size \134\n"
"scgi_busy_buffers_size scgi_cache scgi_cache_bypass scgi_cache_key \134\n"
"scgi_cache_lock scgi_cache_lock_timeout scgi_cache_methods \134\n"
"scgi_cache_min_uses scgi_cache_path scgi_cache_purge \134\n"
"scgi_cache_revalidate scgi_cache_use_stale scgi_cache_valid \134\n"
"scgi_connect_timeout scgi_hide_header scgi_ignore_client_abort \134\n"
"scgi_ignore_headers scgi_intercept_errors scgi_max_temp_file_size \134\n"
"scgi_next_upstream scgi_next_upstream_timeout \134\n"
"scgi_next_upstream_tries scgi_no_cache scgi_param scgi_pass \134\n"
"scgi_pass_header scgi_pass_request_body scgi_pass_request_headers \134\n"
"scgi_read_timeout scgi_send_timeout scgi_store scgi_store_access \134\n"
"scgi_temp_file_write_size scgi_temp_path secure_link secure_link_md5 \134\n"
"secure_link_secret sendfile sendfile_max_chunk send_lowat \134\n"
"send_timeout server server_name server_name_in_redirect \134\n"
"server_names_hash_bucket_size server_names_hash_max_size \134\n"
"server_tokens session_log session_log_format session_log_zone set \134\n"
"set_real_ip_from smtp_auth smtp_capabilities so_keepalive \134\n"
"source_charset spdy_chunk_size spdy_headers_comp split_clients ssi \134\n"
"ssi_last_modified ssi_min_file_chunk ssi_silent_errors ssi_types \134\n"
"ssi_value_length ssl ssl_buffer_size ssl_certificate \134\n"
"ssl_certificate_key ssl_ciphers ssl_client_certificate ssl_crl \134\n"
"ssl_dhparam ssl_ecdh_curve ssl_engine ssl_password_file \134\n"
"ssl_prefer_server_ciphers ssl_protocols ssl_session_cache \134\n"
"ssl_session_ticket_key ssl_session_tickets ssl_session_timeout \134\n"
"ssl_stapling ssl_stapling_file ssl_stapling_responder \134\n"
"ssl_stapling_verify ssl_trusted_certificate ssl_verify_client \134\n"
"ssl_verify_depth starttls status status_format status_zone sticky \134\n"
"sticky_cookie_insert stub_status sub_filter sub_filter_last_modified \134\n"
"sub_filter_once sub_filter_types tcp_nodelay tcp_nopush timeout \134\n"
"timer_resolution try_files types types_hash_bucket_size \134\n"
"types_hash_max_size underscores_in_headers \134\n"
"uninitialized_variable_warn upstream upstream_conf use user userid \134\n"
"userid_domain userid_expires userid_mark userid_name userid_p3p \134\n"
"userid_path userid_service uwsgi_bind uwsgi_buffering uwsgi_buffers \134\n"
"uwsgi_buffer_size uwsgi_busy_buffers_size uwsgi_cache \134\n"
"uwsgi_cache_bypass uwsgi_cache_key uwsgi_cache_lock \134\n"
"uwsgi_cache_lock_timeout uwsgi_cache_methods uwsgi_cache_min_uses \134\n"
"uwsgi_cache_path uwsgi_cache_purge uwsgi_cache_revalidate \134\n"
"uwsgi_cache_use_stale uwsgi_cache_valid uwsgi_connect_timeout \134\n"
"uwsgi_hide_header uwsgi_ignore_client_abort uwsgi_ignore_headers \134\n"
"uwsgi_intercept_errors uwsgi_max_temp_file_size uwsgi_modifier1 \134\n"
"uwsgi_modifier2 uwsgi_next_upstream uwsgi_next_upstream_timeout \134\n"
"uwsgi_next_upstream_tries uwsgi_no_cache uwsgi_param uwsgi_pass \134\n"
"uwsgi_pass_header uwsgi_pass_request_body uwsgi_pass_request_headers \134\n"
"uwsgi_read_timeout uwsgi_send_timeout uwsgi_ssl_ciphers \134\n"
"uwsgi_ssl_crl uwsgi_ssl_name uwsgi_ssl_protocols \134\n"
"uwsgi_ssl_server_name uwsgi_ssl_session_reuse \134\n"
"uwsgi_ssl_trusted_certificate uwsgi_ssl_verify \134\n"
"uwsgi_ssl_verify_depth uwsgi_store uwsgi_store_access \134\n"
"uwsgi_temp_file_write_size uwsgi_temp_path valid_referers \134\n"
"variables_hash_bucket_size variables_hash_max_size \134\n"
"worker_aio_requests worker_connections worker_cpu_affinity \134\n"
"worker_priority worker_processes worker_rlimit_core \134\n"
"worker_rlimit_nofile worker_rlimit_sigpending working_directory \134\n"
"xclient xml_entities xslt_last_modified xslt_param xslt_string_param \134\n"
"xslt_stylesheet xslt_types zone\n"
"\n"
"list deprecated_directive \134\n"
"imap open_file_cache_retest optimize_server_names satisfy_any\n"
;

static CONFIG_SECTION const char builtin_syntax_ninja[] =
"syntax ninja\n"
"\n"
"state line-start code\n"
"char \042 \134t\042 this\n"
"char # comment\n"
"noeat code\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state code\n"
"char \042\134n\042 line-start\n"
"str \042$\134n\042 line-start special\n"
"char -b \134$ dollar\n"
"eat this\n"
"\n"
"state dollar variable\n"
"char -b ' $:' escape\n"
"noeat variable\n"
"\n"
"state variable\n"
"char \042 \134t\042 code\n"
"char \042\134n\042 line-start\n"
"char \042\134x20-\134x7e\134xa1-\134xff\042 this\n"
"eat code error\n"
"\n"
"state escape\n"
"recolor special\n"
"noeat code\n"
;

static CONFIG_SECTION const char builtin_syntax_php[] =
"syntax .php-strvar\n"
"\n"
"state start\n"
"char a-zA-Z_ strvar\n"
"noeat END\n"
"\n"
"state strvar\n"
"char a-zA-Z_0-9 this\n"
"noeat END\n"
"\n"
"syntax .php-strcurly\n"
"\n"
"state strvar\n"
"char } END strvar\n"
"eat this\n"
"\n"
"syntax .php-esc\n"
"\n"
"state special\n"
"char x hex\n"
"char 0-7 oct1\n"
"recolor string 1\n"
"eat END\n"
"\n"
"state hex special\n"
"char 0-9a-fA-F hex2\n"
"recolor string 2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F END special\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"syntax .php-heredoc-common\n"
"\n"
"state bol string\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \042\134n\042 bol\n"
"char \134\134 esc\n"
"char \134$ .php-strvar:this strvar\n"
"str '{$' .php-strcurly:this strvar\n"
"eat this\n"
"\n"
"state esc special\n"
"char 'nrtvf\134$' string special\n"
"noeat .php-esc:string\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"str \042;\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .php-heredoc\n"
"\n"
"state start special\n"
"char \042\134n\042 .php-heredoc-common:END\n"
"noeat END\n"
"\n"
"syntax .php-heredoc-dq\n"
"\n"
"state start special\n"
"str \042\134\042\134n\042 .php-heredoc-common:END\n"
"noeat END\n"
"\n"
"syntax .php-nowdoc\n"
"\n"
"state start special\n"
"str \042'\134n\042 bol\n"
"noeat END\n"
"\n"
"state bol string\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \042\134n\042 bol\n"
"eat this\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"str \042;\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .php\n"
"\n"
"state code\n"
"char -b a-zA-Z_ word\n"
"char \134$ variable\n"
"char \134\042 dq\n"
"char \134' sq\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char ? qm\n"
"str \042//\042 cpp-comment\n"
"str \042/*\042 c-comment\n"
"char # sh-comment\n"
"str <<< heredoc\n"
"eat this\n"
"\n"
"state word code\n"
"char -b a-zA-Z_0-9 this\n"
"inlist keyword code\n"
"inlist constant code\n"
"inlist lang code\n"
"noeat code\n"
"\n"
"state variable\n"
"char -b a-zA-Z_ variable2\n"
"noeat code\n"
"\n"
"state variable2 variable\n"
"char -b a-zA-Z_0-9 this\n"
"bufis this this-keyword\n"
"noeat code\n"
"\n"
"state this-keyword\n"
"recolor this 5\n"
"noeat code\n"
"\n"
"state dq string\n"
"char \134\042 code string\n"
"char \134\134 dqesc\n"
"char \134$ .php-strvar:this strvar\n"
"str '{$' .php-strcurly:this strvar\n"
"eat this\n"
"\n"
"state dqesc special\n"
"char 'nrtvf\134$\042' dq special\n"
"noeat .php-esc:dq\n"
"\n"
"state sq string\n"
"char \134' code string\n"
"char \134\134 sqesc\n"
"eat this\n"
"\n"
"state sqesc string\n"
"char -n \042\134\134'\042 sq\n"
"recolor special 1\n"
"eat sq special\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat check-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat check-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"noeat check-suffix\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"noeat check-suffix\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"noeat check-suffix\n"
"\n"
"state qm tag\n"
"char > END tag\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state cpp-comment comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state c-comment comment\n"
"str \042*/\042 code comment\n"
"eat this\n"
"\n"
"state sh-comment comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state heredoc special\n"
"char -b a-zA-Z_ heredoc-plain\n"
"char \134\042 heredoc-dq-start\n"
"char \134' nowdoc-start\n"
"noeat code\n"
"\n"
"state heredoc-plain special\n"
"char -b a-zA-Z0-9_ this\n"
"heredocbegin .php-heredoc code\n"
"\n"
"state heredoc-dq-start special\n"
"char -b a-zA-Z_ heredoc-dq\n"
"noeat code\n"
"\n"
"state heredoc-dq special\n"
"char -b a-zA-Z0-9_ this\n"
"heredocbegin .php-heredoc-dq code\n"
"\n"
"state nowdoc-start special\n"
"char -b a-zA-Z_ nowdoc\n"
"noeat code\n"
"\n"
"state nowdoc special\n"
"char -b a-zA-Z0-9_ this\n"
"heredocbegin .php-nowdoc code\n"
"\n"
"list keyword \134\n"
"abstract and array as break case catch cfunction class clone \134\n"
"const continue declare default do else elseif enddeclare \134\n"
"endfor endforeach endif endswitch endwhile extends final for \134\n"
"foreach function global goto if implements interface \134\n"
"instanceof namespace new old_function or private protected \134\n"
"public static switch throw try use var while xor self parent\n"
"\n"
"list -i constant \134\n"
"__CLASS__ __DIR__ __FILE__ __FUNCTION__ __METHOD__ __NAMESPACE__ \134\n"
"false null true\n"
"\n"
"list lang \134\n"
"die echo empty exit eval include include_once isset list require \134\n"
"require_once return print unset\n"
"\n"
"syntax php\n"
"\n"
"state code\n"
"char < lab\n"
"eat this\n"
"\n"
"state lab tag\n"
"char ? tag-php\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state tag-php tag\n"
"str \042php\042 tag-ver\n"
"noeat .php:code\n"
"\n"
"state tag-ver tag\n"
"char 3-5 .php:code tag\n"
"noeat .php:code\n"
"\n"
"default special tag\n"
"default keyword lang\n"
"default special strvar\n"
"default variable this\n"
;

static CONFIG_SECTION const char builtin_syntax_python[] =
"require c-uchar\n"
"\n"
"syntax .python-esc\n"
"\n"
"state esc special\n"
"char \042abfnrtv'\134\134\134\042\042 END special\n"
"char 0-7 oct1\n"
"char x hex0\n"
"char u .c-uchar4:END special\n"
"char U .c-uchar8:END special\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex0 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F END special\n"
"noeat END\n"
"\n"
"syntax python\n"
"\n"
"state start code\n"
"char # comment\n"
"str '\042\042\042' longdq\n"
"str \042'''\042 longsq\n"
"char '\042' dq\n"
"char \042'\042 sq\n"
"char -b a-zA-Z_ ident\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \042 \134t\134f\134r\134n\042 whitespace\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state longdq string\n"
"str '\042\042\042' start string\n"
"char -b \042\134\134\042 .python-esc:this\n"
"eat this\n"
"\n"
"state longsq string\n"
"str \042'''\042 start string\n"
"char -b \042\134\134\042 .python-esc:this\n"
"eat this\n"
"\n"
"state dq string\n"
"char \042\134\042\042 start string\n"
"char \042\134n\042 start\n"
"char -b \042\134\134\042 .python-esc:this\n"
"eat this\n"
"\n"
"state sq string\n"
"char \042'\042 start string\n"
"char \042\134n\042 start\n"
"char -b \042\134\134\042 .python-esc:this\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z_0-9 this\n"
"inlist keyword start\n"
"inlist constant start\n"
"noeat start\n"
"\n"
"state zero numeric\n"
"char bB bin\n"
"char oO oct\n"
"char xX hex\n"
"char 0 dec-zero\n"
"char . float\n"
"char eE exponent\n"
"noeat int-suffix\n"
"\n"
"state bin numeric\n"
"char 01 this\n"
"noeat int-suffix\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat int-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exponent\n"
"char . float\n"
"noeat int-suffix\n"
"\n"
"state dec-zero numeric\n"
"char 0 this\n"
"char eE exponent\n"
"char . float\n"
"noeat int-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat int-suffix\n"
"\n"
"state int-suffix code\n"
"char lL int-end numeric\n"
"char jJ float-end numeric\n"
"noeat int-end\n"
"\n"
"state int-end error\n"
"char a-zA-Z0-9_ this\n"
"noeat start\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exponent\n"
"noeat float-suffix\n"
"\n"
"state exponent numeric\n"
"char +- exponent-sign\n"
"char 0-9 exponent-digit\n"
"recolor error 1\n"
"noeat float-end\n"
"\n"
"state exponent-sign numeric\n"
"char 0-9 exponent-digit\n"
"recolor error 2\n"
"noeat float-end\n"
"\n"
"state exponent-digit numeric\n"
"char 0-9 this\n"
"noeat float-suffix\n"
"\n"
"state float-suffix code\n"
"char jJ float-end numeric\n"
"noeat int-end\n"
"\n"
"state float-end error\n"
"char a-zA-Z_ this\n"
"noeat start\n"
"\n"
"state whitespace\n"
"char \042 \134t\134f\134r\134n\042 this\n"
"char . whitespace-dot\n"
"noeat start\n"
"\n"
"state whitespace-dot code\n"
"char 0-9 dot-float\n"
"noeat start\n"
"\n"
"state dot-float numeric\n"
"recolor numeric 2\n"
"noeat float\n"
"\n"
"state dot code\n"
"char 0-9 this error\n"
"noeat start\n"
"\n"
"list keyword \134\n"
"and as assert break class continue def del elif else except exec \134\n"
"finally for from global if import in is lambda not or pass print \134\n"
"raise return try while with yield\n"
"\n"
"list constant \134\n"
"None False True\n"
;

static CONFIG_SECTION const char builtin_syntax_robotstxt[] =
"syntax robotstxt\n"
"\n"
"list -i field user-agent: disallow: allow: crawl-delay: sitemap: host:\n"
"\n"
"state main code\n"
"char -b A-Za-z firstword\n"
"char # comment\n"
"char \042 \134t\042 this\n"
"noeat remainder\n"
"\n"
"state firstword\n"
"char -b A-Za-z- this\n"
"char -b : field\n"
"noeat -b remainder\n"
"\n"
"state field\n"
"inlist field value keyword\n"
"recolor error\n"
"noeat remainder\n"
"\n"
"state value\n"
"char # comment\n"
"char \042\134n\042 main\n"
"eat this\n"
"\n"
"state remainder error\n"
"recolor error\n"
"char # comment\n"
"char \042\134n\042 main\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 main\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_roff[] =
"syntax roff\n"
"\n"
"state line-start\n"
"char -b '.' request\n"
"char \042\134n\042 this\n"
"noeat text\n"
"\n"
"state request\n"
"char -b a-zA-Z this\n"
"inlist section section\n"
"noeat text\n"
"\n"
"state escape-start escape\n"
"char -b '\042#' comment\n"
"char -b f font-selection\n"
"char -b ( 2char-escape\n"
"char \042 \134\134.%!|^&)/~:{}acdeEprtu-\042 text escape\n"
"eat text error\n"
"\n"
"state 2char-escape escape\n"
"char -b \042A-Za-z0-9_<>=!?$%*|/'\134\042:^,~.`+-\042 2char-escape-2\n"
"recolor error\n"
"char \042\134n\042 line-start\n"
"eat text error\n"
"\n"
"state 2char-escape-2 escape\n"
"char \042A-Za-z0-9_<>=!?$%*|/'\134\042:^,~.`+-\042 text escape\n"
"recolor error\n"
"char \042\134n\042 line-start\n"
"eat text error\n"
"\n"
"state font-selection escape\n"
"char -b RBI text escape\n"
"noeat text\n"
"\n"
"state text\n"
"char -b '\134\134' escape-start\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state comment\n"
"recolor comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state section\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"list section .SH .SS\n"
"\n"
"default special escape\n"
"default string request\n"
"default keyword section\n"
;

static CONFIG_SECTION const char builtin_syntax_ruby[] =
"syntax .ruby-esc\n"
"\n"
"state esc special\n"
"char \042abefnrstv'\134\134\134\042\042 END special\n"
"char 0-7 oct1\n"
"char x hex0\n"
"char c control\n"
"str 'C-' control\n"
"str 'M-' meta\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 oct2\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex0 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F END special\n"
"noeat END\n"
"\n"
"state control special\n"
"str \042\134\134M-\042 ascii-print\n"
"noeat ascii-print\n"
"\n"
"state meta special\n"
"str \042\134\134c\042 ascii-print\n"
"str \042\134\134C-\042 ascii-print\n"
"noeat ascii-print\n"
"\n"
"state ascii-print special\n"
"char \042\134x21-\134x7e\042 END special\n"
"noeat END\n"
"\n"
"syntax ruby\n"
"\n"
"\n"
"state line-start code\n"
"char \042\134n\042 this\n"
"char = line-start-eq\n"
"noeat start\n"
"\n"
"state start code\n"
"char # comment\n"
"char \042\134n\042 line-start\n"
"char -b a-zA-Z_ ident\n"
"char '\042' dq\n"
"char \042'\042 sq\n"
"char \134$ global-variable\n"
"char -b @ maybe-instance-variable\n"
"char -b : maybe-symbol\n"
"eat this\n"
"\n"
"state global-variable\n"
"char a-zA-Z0-9_- this\n"
"char !@&`\134'+~=/\134\134,\134;.<>*\134$?:\134\042 start global-variable\n"
"noeat start\n"
"\n"
"state maybe-instance-variable instance-variable\n"
"char -b a-zA-Z_ instance-variable\n"
"recolor code\n"
"noeat start\n"
"\n"
"state instance-variable\n"
"char a-zA-Z0-9_ this\n"
"noeat start\n"
"\n"
"state maybe-symbol symbol\n"
"char -b !~*/%+<>&|^=- maybe-symbol-op\n"
"char -b @ maybe-symbol-at\n"
"char -b a-zA-Z_ symbol\n"
"char '\042' symbol-dq\n"
"char \042'\042 symbol-sq\n"
"char -b : double-colon\n"
"recolor code\n"
"noeat start\n"
"\n"
"state double-colon\n"
"recolor double-colon\n"
"noeat start\n"
"\n"
"state maybe-symbol-op symbol\n"
"char -b <>=~ this\n"
"inlist symbol-operators start symbol\n"
"recolor code\n"
"noeat start\n"
"\n"
"state maybe-symbol-at symbol\n"
"char a-zA-Z_ symbol\n"
"recolor code\n"
"noeat start\n"
"\n"
"state symbol\n"
"char a-zA-Z0-9_ this\n"
"noeat symbol-end\n"
"\n"
"state symbol-dq symbol\n"
"char \042\134\042\042 start symbol\n"
"char -b \042\134\134\042 .ruby-esc:this\n"
"eat this\n"
"\n"
"state symbol-sq symbol\n"
"char \042'\042 start symbol\n"
"char -b \042\134\134\042 symbol-sq-esc symbol\n"
"eat this\n"
"\n"
"state symbol-sq-esc special\n"
"char -b \042'\134\134\042 symbol-sq special\n"
"recolor symbol\n"
"noeat symbol-sq\n"
"\n"
"state symbol-end\n"
"char !? start symbol\n"
"noeat start\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state line-start-eq comment\n"
"str 'begin' =begin\n"
"recolor code 1\n"
"noeat start\n"
"\n"
"state =begin comment\n"
"char \042\134n\042 =begin-line-start\n"
"char \042 \134t\042 =begin-text\n"
"recolor code 6\n"
"noeat start\n"
"\n"
"state =begin-text comment\n"
"char \042\134n\042 =begin-line-start\n"
"eat this\n"
"\n"
"state =begin-line-start comment\n"
"char \042\134n\042 this\n"
"str '=end' =begin-maybe-end\n"
"noeat =begin-text\n"
"\n"
"state =begin-maybe-end comment\n"
"char \042\134n\042 line-start\n"
"char \042 \134t\042 =end\n"
"noeat =begin-text\n"
"\n"
"state =end comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_!? this\n"
"inlist keyword start\n"
"inlist true-false-nil start\n"
"noeat start\n"
"\n"
"state dq string\n"
"char \042\134\042\042 start string\n"
"char -b \042\134\134\042 .ruby-esc:this\n"
"eat this\n"
"\n"
"state sq string\n"
"char \042'\042 start string\n"
"char -b \042\134\134\042 sq-esc\n"
"eat this\n"
"\n"
"state sq-esc special\n"
"char \042'\134\134\042 sq special\n"
"recolor string\n"
"noeat sq\n"
"\n"
"list keyword \134\n"
"__ENCODING__ __LINE__ __FILE__ BEGIN END \134\n"
"alias and begin break case class def defined? do else elsif end \134\n"
"ensure for if in module next not or redo rescue retry return self \134\n"
"super then undef unless until when while yield\n"
"\n"
"list true-false-nil \134\n"
"true false nil\n"
"\n"
"list symbol-operators \134\n"
":! :~ :* :/ :% :+ :- :<< :>> :& :| :^ :< :<=  :>= :> :== :=== :!= :=~ :!~ :<=>\n"
"\n"
"default keyword true-false-nil\n"
"default numeric symbol\n"
"default variable global-variable\n"
"default variable instance-variable\n"
"default operator double-colon\n"
;

static CONFIG_SECTION const char builtin_syntax_scheme[] =
"syntax scheme\n"
"\n"
"state start code\n"
"char \042;\042 comment\n"
"char '\042' string\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state string\n"
"char \042\134\042\042 start string\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_sed[] =
"syntax sed\n"
"\n"
"state line-start\n"
"char \042 \134t\134n\042 this\n"
"char # comment\n"
"noeat code\n"
"\n"
"state code\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_sh[] =
"syntax .sh-sq\n"
"\n"
"state string\n"
"char \042'\042 END string\n"
"eat this\n"
"\n"
"syntax .sh-dq-escape\n"
"\n"
"state special\n"
"char '\042$\134`'\042\134n\042 END special\n"
"recolor string 1\n"
"eat END\n"
"\n"
"syntax .sh-command-escape\n"
"\n"
"state special\n"
"eat END special\n"
"\n"
"syntax .sh-var\n"
"\n"
"state variable\n"
"char '{' brace1\n"
"char '*@#?$!0-9-' END variable\n"
"char a-zA-Z_ name\n"
"noeat END\n"
"\n"
"state name variable\n"
"char a-zA-Z_0-9 this\n"
"noeat END\n"
"\n"
"state brace1 variable\n"
"char } END variable\n"
"str '${' brace2\n"
"eat this\n"
"\n"
"state brace2 variable\n"
"char } brace1 variable\n"
"str '${' brace3\n"
"eat this\n"
"\n"
"state brace3 variable\n"
"char } brace2 variable\n"
"str '${' END error\n"
"eat this\n"
"\n"
"syntax .sh-expression\n"
"\n"
"state expression special\n"
"str '))' END special\n"
"eat this\n"
"\n"
"syntax .sh-simple-dq\n"
"\n"
"state string\n"
"char \134\042 END string\n"
"char \134\134 .sh-dq-escape:this\n"
"char \134$ special\n"
"eat this\n"
"\n"
"state special\n"
"char '(' paren\n"
"recolor variable 1\n"
"noeat .sh-var:string\n"
"\n"
"state paren special\n"
"char '(' .sh-expression:string\n"
"noeat command\n"
"\n"
"state command\n"
"char ')' string special\n"
"char -n \042\134n\042 this\n"
"noeat string\n"
"\n"
"syntax .sh-pcommand\n"
"\n"
"state command\n"
"char ')' END special\n"
"char \134' .sh-sq:this\n"
"char \134\042 .sh-simple-dq:this\n"
"char \134\134 .sh-command-escape:this\n"
"char \134$ .sh-var:this\n"
"eat this\n"
"\n"
"syntax .sh-dollar\n"
"\n"
"state special\n"
"char '(' paren\n"
"recolor variable 1\n"
"noeat .sh-var:END\n"
"\n"
"state paren special\n"
"char '(' .sh-expression:END\n"
"noeat .sh-pcommand:END\n"
"\n"
"syntax .sh-backtick\n"
"\n"
"state special\n"
"char \134' .sh-sq:this\n"
"char \134\042 .sh-simple-dq:this\n"
"char \134\134 .sh-command-escape:this\n"
"char \134$ .sh-var:this\n"
"char ` END special\n"
"eat this\n"
"\n"
"syntax .sh-dq\n"
"\n"
"state string\n"
"char '\042' END string\n"
"char \134\134 .sh-dq-escape:this\n"
"char ` .sh-backtick:this\n"
"char \134$ .sh-dollar:this\n"
"eat this\n"
"\n"
"syntax .sh-heredoc-skip-line\n"
"\n"
"state start\n"
"char \042\134n\042 END\n"
"eat this code\n"
"\n"
"\n"
"syntax .sh-heredoc-common\n"
"\n"
"state start\n"
"noeat .sh-heredoc-skip-line:bol\n"
"\n"
"state bol string\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \042\134n\042 bol\n"
"eat this\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .sh-heredoc\n"
"\n"
"state start code\n"
"noeat .sh-heredoc-skip-line:bol\n"
"\n"
"state bol string\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \134\134 esc\n"
"char \042\134n\042 bol\n"
"char \134` .sh-backtick:this\n"
"char \134$ .sh-dollar:this\n"
"eat this\n"
"\n"
"state esc special\n"
"char \042\134n\134\134`$\042 string special\n"
"recolor error 1\n"
"noeat string\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .sh-heredoc-dq\n"
"\n"
"state start string\n"
"char -n \134\042 END error\n"
"eat .sh-heredoc-common:END\n"
"\n"
"syntax .sh-heredoc-sq\n"
"\n"
"state start string\n"
"char -n \134' END error\n"
"eat .sh-heredoc-common:END\n"
"\n"
"\n"
"syntax .sh-heredoc-hyphen-common\n"
"\n"
"state start\n"
"noeat .sh-heredoc-skip-line:bol\n"
"\n"
"state bol string\n"
"char \042\134t\042 this\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \042\134n\042 bol\n"
"eat this\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .sh-heredoc-hyphen\n"
"\n"
"state start code\n"
"noeat .sh-heredoc-skip-line:bol\n"
"\n"
"state bol string\n"
"char \042\134t\042 this\n"
"heredocend match\n"
"noeat string\n"
"\n"
"state string\n"
"char \134\134 esc\n"
"char \042\134n\042 bol\n"
"char \134` .sh-backtick:this\n"
"char \134$ .sh-dollar:this\n"
"eat this\n"
"\n"
"state esc special\n"
"char \042\134n\134\134`$\042 string special\n"
"recolor error 1\n"
"noeat string\n"
"\n"
"state match special\n"
"char \042\134n\042 END\n"
"recolor string 1000\n"
"noeat string\n"
"\n"
"syntax .sh-heredoc-hyphen-dq\n"
"\n"
"state start string\n"
"char -n \134\042 END error\n"
"eat .sh-heredoc-hyphen-common:END\n"
"\n"
"syntax .sh-heredoc-hyphen-sq\n"
"\n"
"state start string\n"
"char -n \134' END error\n"
"eat .sh-heredoc-hyphen-common:END\n"
"\n"
"\n"
"syntax sh\n"
"\n"
"state start code\n"
"char -b a-zA-Z0-9_/.- command\n"
"char \042\134t \042 this\n"
"char '({' this special\n"
"noeat args\n"
"\n"
"state command code\n"
"char -b a-zA-Z0-9_/.- this\n"
"inlist keyword1 start keyword\n"
"inlist keyword2 args keyword\n"
"inlist builtin args\n"
"bufis for for\n"
"char \134( function\n"
"noeat args\n"
"\n"
"state function special\n"
"char \134) start special\n"
"eat start error\n"
"\n"
"state for keyword\n"
"char \042 \134t\042 this\n"
"char a-zA-Z_ forvar\n"
"noeat forerror\n"
"\n"
"state forvar ident\n"
"char a-zA-Z_0-9 this\n"
"char \042 \134t\042 forspace\n"
"noeat forerror\n"
"\n"
"state forspace code\n"
"char \042 \134t\042 this\n"
"str in in\n"
"noeat forerror\n"
"\n"
"state in keyword\n"
"char \042 \134t\042 args\n"
"noeat forerror\n"
"\n"
"state forerror code\n"
"char a-zA-Z_0-9 args error\n"
"noeat args\n"
"\n"
"state args code\n"
"char # comment\n"
"char \042'\042 .sh-sq:this\n"
"char '\042' .sh-dq:this\n"
"char \134\134 .sh-command-escape:this\n"
"char ` .sh-backtick:this\n"
"char \134$ .sh-dollar:this\n"
"char \042\134n\042 start\n"
"char ';&|' start special\n"
"char ()} this special\n"
"char < lt\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state lt special\n"
"char < lt2\n"
"noeat args\n"
"\n"
"state lt2 special\n"
"char < lt3\n"
"char -- - heredoc-hyphen-start special\n"
"noeat heredoc-start\n"
"\n"
"state lt3 special\n"
"noeat args\n"
"\n"
"state heredoc-start special\n"
"char \042 \134t\042 this\n"
"char \134\042 heredoc-dq\n"
"char \134' heredoc-sq\n"
"char \042\134n\042 start error\n"
"noeat heredoc\n"
"\n"
"state heredoc-dq string\n"
"char -bn \042\134\042\134n\042 this\n"
"heredocbegin .sh-heredoc-dq start\n"
"\n"
"state heredoc-sq string\n"
"char -bn \042\134'\134n\042 this\n"
"heredocbegin .sh-heredoc-sq start\n"
"\n"
"state heredoc special\n"
"char -bn \042 \134t\134n;|>\042 this\n"
"heredocbegin .sh-heredoc start\n"
"\n"
"state heredoc-hyphen-start special\n"
"char \042 \134t\042 this\n"
"char \134\042 heredoc-hyphen-dq\n"
"char \134' heredoc-hyphen-sq\n"
"char \042\134n\042 start error\n"
"noeat heredoc-hyphen\n"
"\n"
"state heredoc-hyphen-dq string\n"
"char -bn \042\134\042\134n\042 this\n"
"heredocbegin .sh-heredoc-hyphen-dq start\n"
"\n"
"state heredoc-hyphen-sq string\n"
"char -bn \042\134'\134n\042 this\n"
"heredocbegin .sh-heredoc-hyphen-sq start\n"
"\n"
"state heredoc-hyphen special\n"
"char -bn \042 \134t\134n;|>\042 this\n"
"heredocbegin .sh-heredoc-hyphen start\n"
"\n"
"list keyword1 \134\n"
"do else elif exec if then until while\n"
"\n"
"list keyword2 \134\n"
"break case continue done esac exit export fi function in return shift\n"
"\n"
"list builtin \134\n"
"alias bg bind cd caller command compgen complete test kill source \134\n"
"time declare typeset dirs disown echo enable eval fc fg getopts hash \134\n"
"help history jobs let local logout popd printf pushd pwd read \134\n"
"readonly shopt set trap type ulimit umask unalias unset wait \042.\042\n"
"\n"
"default special expression\n"
;

static CONFIG_SECTION const char builtin_syntax_sql[] =
"syntax .sql-esc\n"
"\n"
"state esc special\n"
"char \0420'\134\042bnrtZ\134\134%_\042 END special\n"
"noeat END\n"
"\n"
"syntax sql\n"
"\n"
"state start code\n"
"char \042'\042 sq\n"
"char '\042' dq\n"
"char -b bB b\n"
"char -b xX x\n"
"char -b a-zA-Z_\134$ word\n"
"char 0 zero\n"
"char 1-9 int\n"
"char . float\n"
"char @ at\n"
"char ` backtick\n"
"char -- - dash\n"
"char # comment\n"
"char / slash\n"
"eat this\n"
"\n"
"state zero numeric\n"
"char 0-9 int\n"
"char . float\n"
"char b bin\n"
"char x hex\n"
"noeat trailing\n"
"\n"
"state int numeric\n"
"char 0-9 this\n"
"char . float\n"
"noeat trailing\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"noeat trailing\n"
"\n"
"state bin numeric\n"
"char 01 bindigit\n"
"eat start error\n"
"\n"
"state bindigit numeric\n"
"char 01 this\n"
"noeat trailing\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F hexdigit\n"
"eat start error\n"
"\n"
"state hexdigit numeric\n"
"char 0-9a-fA-F this\n"
"noeat trailing\n"
"\n"
"state b code\n"
"char \134' bitstr\n"
"noeat -b word\n"
"\n"
"state bitstr\n"
"recolor string 2\n"
"noeat bitstrbit\n"
"\n"
"state bitstrbit special\n"
"char 01 this\n"
"char \042\134n'\042 start string\n"
"eat this error\n"
"\n"
"state x code\n"
"char \134' hexstr\n"
"noeat -b word\n"
"\n"
"state hexstr\n"
"recolor string 2\n"
"noeat hexstreven\n"
"\n"
"state hexstreven special\n"
"char 0-9a-fA-F hexstrodd\n"
"char \042\134n'\042 start string\n"
"eat hexstrodd error\n"
"\n"
"state hexstrodd special\n"
"char 0-9a-fA-F hexstreven\n"
"char \042\134n'\042 start error\n"
"eat hexstreven error\n"
"\n"
"state word code\n"
"char -b a-zA-Z0-9_\134$ this\n"
"inlist keyword start\n"
"inlist identifier start\n"
"char . column code\n"
"noeat start\n"
"\n"
"state column\n"
"char -b a-zA-Z0-9_\134$ this\n"
"noeat start\n"
"\n"
"state at variable\n"
"char a-zA-Z0-9._\134$ variable\n"
"char \042'\042 sq\n"
"char '\042' dq\n"
"char ` backtick\n"
"eat start error\n"
"\n"
"state variable\n"
"char a-zA-Z0-9._\134$ this\n"
"noeat start\n"
"\n"
"state sq string\n"
"char \042\134n'\042 start string\n"
"char \134\134 .sql-esc:this\n"
"eat this\n"
"\n"
"state dq string\n"
"char \042\134n\042\134\042 start string\n"
"char \134\134 .sql-esc:this\n"
"eat this\n"
"\n"
"state backtick constant\n"
"char \042\134n`\042 start\n"
"eat this\n"
"\n"
"state dash comment\n"
"char -- - maybe-comment\n"
"recolor code 1\n"
"noeat start\n"
"\n"
"state maybe-comment comment\n"
"char \042\134n\042 start\n"
"char \042\134x01- \042 comment\n"
"recolor code 2\n"
"noeat start\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state slash comment\n"
"char \042*\042 maybe-c-comment\n"
"recolor code 1\n"
"noeat start\n"
"\n"
"state maybe-c-comment comment\n"
"char ! begin-special-comment\n"
"noeat c-comment\n"
"\n"
"state begin-special-comment\n"
"recolor special 3\n"
"noeat special-comment\n"
"\n"
"state special-comment special\n"
"char \042*\042 scstar\n"
"eat this\n"
"\n"
"state scstar special\n"
"char / start special\n"
"noeat special-comment\n"
"\n"
"state c-comment comment\n"
"char \042*\042 star\n"
"eat this\n"
"\n"
"state star comment\n"
"char / start comment\n"
"noeat c-comment\n"
"\n"
"state trailing error\n"
"char a-zA-Z0-9_\134$ this\n"
"noeat start\n"
"\n"
"list -i keyword \134\n"
"ACCESSIBLE \134\n"
"ADD ALL ALTER ANALYZE AND AS ASC ASENSITIVE BEFORE BETWEEN \134\n"
"BIGINT BINARY BLOB BOTH BY CALL CASCADE CASE CHANGE CHAR \134\n"
"CHARACTER CHECK COLLATE COLUMN CONDITION CONSTRAINT CONTINUE \134\n"
"CONVERT CREATE CROSS CURRENT_DATE CURRENT_TIME \134\n"
"CURRENT_TIMESTAMP CURRENT_USER CURSOR DATABASE DATABASES \134\n"
"DAY_HOUR DAY_MICROSECOND DAY_MINUTE DAY_SECOND DEC DECIMAL \134\n"
"DECLARE DEFAULT DELAYED DELETE DESC DESCRIBE DETERMINISTIC \134\n"
"DISTINCT DISTINCTROW DIV DOUBLE DROP DUAL EACH ELSE ELSEIF \134\n"
"ENCLOSED ESCAPED EXISTS EXIT EXPLAIN FALSE FETCH FLOAT FLOAT4 \134\n"
"FLOAT8 FOR FORCE FOREIGN FROM FULLTEXT GRANT GROUP HAVING \134\n"
"HIGH_PRIORITY HOUR_MICROSECOND HOUR_MINUTE HOUR_SECOND IF \134\n"
"IGNORE IN INDEX INFILE INNER INOUT INSENSITIVE INSERT INT INT1 \134\n"
"INT2 INT3 INT4 INT8 INTEGER INTERVAL INTO IS ITERATE JOIN KEY \134\n"
"KEYS KILL LEADING LEAVE LEFT LIKE LIMIT LINEAR LINES LOAD LOCALTIME \134\n"
"LOCALTIMESTAMP LOCK LONG LONGBLOB LONGTEXT LOOP LOW_PRIORITY \134\n"
"MASTER_BIND MASTER_SSL_VERIFY_SERVER_CERT \134\n"
"MATCH MAXVALUE MEDIUMBLOB MEDIUMINT MEDIUMTEXT MIDDLEINT \134\n"
"MINUTE_MICROSECOND MINUTE_SECOND MOD MODIFIES NATURAL NOT \134\n"
"NO_WRITE_TO_BINLOG NULL NUMERIC ON ONE_SHOT OPTIMIZE OPTION OPTIONALLY \134\n"
"OR ORDER OUT OUTER OUTFILE PARTITION PRECISION PRIMARY PROCEDURE PURGE RANGE \134\n"
"READ READS READ_WRITE REAL REFERENCES REGEXP RELEASE RENAME REPEAT \134\n"
"REPLACE REQUIRE RESIGNAL RESTRICT RETURN REVOKE RIGHT RLIKE SCHEMA \134\n"
"SCHEMAS SECOND_MICROSECOND SELECT SENSITIVE SEPARATOR SET \134\n"
"SHOW SIGNAL SMALLINT SPATIAL SPECIFIC SQL SQLEXCEPTION \134\n"
"SQLSTATE SQLWARNING SQL_BIG_RESULT SQL_CALC_FOUND_ROWS \134\n"
"SQL_SMALL_RESULT SSL STARTING STRAIGHT_JOIN TABLE TERMINATED \134\n"
"THEN TINYBLOB TINYINT TINYTEXT TO TRAILING TRIGGER TRUE UNDO \134\n"
"UNION UNIQUE UNLOCK UNSIGNED UPDATE USAGE USE USING UTC_DATE \134\n"
"UTC_TIME UTC_TIMESTAMP VALUES VARBINARY VARCHAR VARCHARACTER \134\n"
"VARYING WHEN WHERE WHILE WITH WRITE XOR YEAR_MONTH ZEROFILL\n"
"\n"
"list -i identifier \134\n"
"ACTION BIT DATE ENUM NO TEXT TIME TIMESTAMP\n"
"\n"
"default keyword identifier\n"
"default code column\n"
;

static CONFIG_SECTION const char builtin_syntax_tex[] =
"syntax tex\n"
"\n"
"\n"
"state text\n"
"char \134\134 backslash\n"
"char % comment\n"
"eat this\n"
"\n"
"state backslash macro\n"
"char A-Za-z macro\n"
"char \042\134\134,;{}\042 escape\n"
"eat text error\n"
"\n"
"state macro\n"
"char A-Za-z this\n"
"noeat text\n"
"\n"
"state escape\n"
"recolor special 2\n"
"noeat text\n"
"\n"
"state comment\n"
"char \042\134n\042 text\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_texmfcnf[] =
"syntax texmfcnf\n"
"\n"
"state line-start\n"
"char \042\134n\042 this\n"
"char % comment\n"
"noeat text\n"
"\n"
"state text\n"
"char \042\134n\042 line-start\n"
"char \042 \134t\042 space\n"
"char \134$ dollar\n"
"eat this\n"
"\n"
"state space\n"
"char \042 \134t\042 this\n"
"char % comment\n"
"noeat text\n"
"\n"
"state comment\n"
"char \042\134n\042 line-start\n"
"eat this\n"
"\n"
"state dollar variable\n"
"char A-Za-z_ variable\n"
"char { brace\n"
"noeat text\n"
"\n"
"state variable\n"
"char A-Za-z0-9_ this\n"
"noeat text\n"
"\n"
"state brace variable\n"
"char \042\134n\042 line-start\n"
"char } text variable\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_tmux[] =
"syntax tmux\n"
"\n"
"state start code\n"
"char \042 \134t\042 this\n"
"char # comment\n"
"noeat command\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state command code\n"
"char \042\134n\042 start\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_vala[] =
"syntax .vala-esc\n"
"\n"
"state char-esc special\n"
"char \042bfnrt\134\134'\134\042\042 END special\n"
"char 0 oct\n"
"char u hex4\n"
"noeat short\n"
"\n"
"state oct special\n"
"char 0-3 oct2\n"
"char 4-7 oct1\n"
"noeat END\n"
"\n"
"state oct2 special\n"
"char 0-7 oct1\n"
"noeat END\n"
"\n"
"state oct1 special\n"
"char 0-7 END special\n"
"noeat END\n"
"\n"
"state hex4 special\n"
"char 0-9a-fA-F hex3\n"
"noeat END\n"
"\n"
"state hex3 special\n"
"char 0-9a-fA-F hex2\n"
"noeat END\n"
"\n"
"state hex2 special\n"
"char 0-9a-fA-F hex1\n"
"noeat END\n"
"\n"
"state hex1 special\n"
"char 0-9a-fA-F END special\n"
"noeat END\n"
"\n"
"state short special\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"char -n \042\134n\042 END error\n"
"noeat END\n"
"\n"
"state not-ascii error\n"
"char \042\134x80-\134xff\042 this\n"
"noeat END\n"
"\n"
"syntax vala\n"
"\n"
"state code\n"
"char -b a-zA-Z_ ident\n"
"char 0 zero\n"
"char 1-9 dec\n"
"char . dot\n"
"char \134\042 string\n"
"char \134' char\n"
"str \042//\042 cpp-comment\n"
"str \042/*\042 c-comment\n"
"eat this\n"
"\n"
"state cpp-comment comment\n"
"char \042\134n\042 code\n"
"eat this\n"
"\n"
"state c-comment comment\n"
"str \042*/\042 code comment\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword code\n"
"inlist type code\n"
"inlist constant code\n"
"noeat code\n"
"\n"
"state zero numeric\n"
"char xX hex\n"
"char 0-7 oct\n"
"char . float\n"
"noeat num-suffix\n"
"\n"
"state oct numeric\n"
"char 0-7 this\n"
"noeat num-suffix\n"
"\n"
"state dec numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"char . float\n"
"noeat num-suffix\n"
"\n"
"state hex numeric\n"
"char 0-9a-fA-F this\n"
"noeat num-suffix\n"
"\n"
"state num-suffix\n"
"char lLfFdD check-suffix numeric\n"
"noeat check-suffix\n"
"\n"
"state float-suffix\n"
"char fFdD check-suffix numeric\n"
"noeat check-suffix\n"
"\n"
"state check-suffix error\n"
"char a-zA-Z0-9_ this\n"
"noeat code\n"
"\n"
"state dot numeric\n"
"char 0-9 float\n"
"recolor code 1\n"
"noeat code\n"
"\n"
"state float numeric\n"
"char 0-9 this\n"
"char eE exp\n"
"noeat float-suffix\n"
"\n"
"state exp numeric\n"
"char +- exp-digit\n"
"char 0-9 exp-digit\n"
"noeat float-suffix\n"
"\n"
"state exp-digit numeric\n"
"char 0-9 this\n"
"noeat float-suffix\n"
"\n"
"state string\n"
"char \134\134 .vala-esc:this\n"
"char \134\042 code string\n"
"eat this\n"
"\n"
"state char\n"
"char \042\134\134\042 .vala-esc:char-end\n"
"char \042\134n\042 code\n"
"char \134' code error\n"
"char \042\134x80-\134xff\042 not-ascii\n"
"eat char-end\n"
"\n"
"state not-ascii char\n"
"char \042\134x80-\134xff\042 this\n"
"noeat char-end\n"
"\n"
"state char-end char\n"
"char \134' code char\n"
"eat code error\n"
"\n"
"list keyword \134\n"
"if else switch case default do while for foreach in break continue \134\n"
"return try catch finally throw lock class interface struct enum \134\n"
"delegate errordomain const weak unowned dynamic abstract virtual \134\n"
"override signal extern static async inline new public private \134\n"
"protected internal out ref throws requires ensures namespace using \134\n"
"as is in new delete sizeof typeof this base null true false get set \134\n"
"construct default value construct static construct class construct \134\n"
"void var yield global owned\n"
"\n"
"list type \134\n"
"bool char uchar short ushort int uint long ulong size_t ssize_t int8 \134\n"
"uint8 int16 uint16 int32 uint32 int64 uint64 unichar float double string\n"
"\n"
"list constant \134\n"
"false true null\n"
;

static CONFIG_SECTION const char builtin_syntax_xml[] =
"syntax .xml-entity\n"
"\n"
"state entity\n"
"char # hash\n"
"char -b a-zA-Z0-9 name\n"
"recolor error 1\n"
"char \042\134n\042 END\n"
"eat END error\n"
"\n"
"state hash entity\n"
"char xX x\n"
"char 0-9 dec\n"
"eat END error\n"
"\n"
"state x entity\n"
"char 0-9a-fA-F hex\n"
"eat END error\n"
"\n"
"state hex entity\n"
"char 0-9a-fA-F this\n"
"char \042;\042 END entity\n"
"eat END error\n"
"\n"
"state dec entity\n"
"char 0-9 this\n"
"char \042;\042 END entity\n"
"eat END error\n"
"\n"
"state name error\n"
"char -b a-zA-Z0-9 this\n"
"inlist entity semicolon\n"
"noeat semicolon\n"
"\n"
"state semicolon error\n"
"char \042;\042 END entity\n"
"eat END error\n"
"\n"
"list entity \134\n"
"quot apos amp lt gt\n"
"\n"
"syntax xml\n"
"\n"
"state line1 text\n"
"char \042 \134t\134n\042 this\n"
"str \042<?\042 xml\n"
"str -i \042<!doctype\042 doctype\n"
"noeat text\n"
"\n"
"state line2 text\n"
"char \042 \134t\134n\042 this\n"
"str -i \042<!doctype\042 doctype\n"
"noeat text\n"
"\n"
"state xml comment\n"
"char > line2 comment\n"
"char < line2 error\n"
"eat this\n"
"\n"
"state doctype comment\n"
"char > text comment\n"
"char < text error\n"
"eat this\n"
"\n"
"state text\n"
"str \042<!\042 maybe-comment-or-cdata\n"
"char < tag-start\n"
"char > this error\n"
"char \042&\042 .xml-entity:this\n"
"eat this\n"
"\n"
"state maybe-comment-or-cdata comment\n"
"str -- '--' comment\n"
"str '[CDATA[' cdata-open\n"
"recolor error 2\n"
"noeat tag-start\n"
"\n"
"state comment\n"
"str -- '-->' text comment\n"
"eat this\n"
"\n"
"state cdata-open\n"
"recolor cdata-delim 9\n"
"noeat cdata\n"
"\n"
"state cdata\n"
"char ] cdata-maybe-close\n"
"eat this\n"
"\n"
"state cdata-maybe-close cdata\n"
"str ']>' cdata-close\n"
"noeat cdata\n"
"\n"
"state cdata-close\n"
"recolor cdata-delim 3\n"
"noeat text\n"
"\n"
"state tag-start tag\n"
"char / close-tag\n"
"char -b a-zA-Z_: tag-name\n"
"char > text tag\n"
"eat this error\n"
"\n"
"state close-tag tag\n"
"char -b a-zA-Z_: close-tag-name\n"
"eat text error\n"
"\n"
"state tag-name tag\n"
"char -b a-zA-Z0-9_:.- this\n"
"noeat attrs\n"
"\n"
"state close-tag-name tag\n"
"char -b a-zA-Z0-9_:.- this\n"
"noeat close-tag-end\n"
"\n"
"state close-tag-end special\n"
"char \042 \134t\134n\042 this\n"
"char > text tag\n"
"eat text error\n"
"\n"
"state attrs code\n"
"char \042 \134t\134n\042 this\n"
"char -b a-zA-Z:_ attr-name\n"
"char > text tag\n"
"char / short-close\n"
"eat this error\n"
"\n"
"state short-close tag\n"
"char > text tag\n"
"eat text error\n"
"\n"
"state attr-name attr\n"
"char a-zA-Z0-9_:.- this\n"
"char = attr-eq\n"
"noeat attrs\n"
"\n"
"state attr-eq attr\n"
"char \134\042 dq\n"
"char \134' sq\n"
"noeat attrs\n"
"\n"
"state dq string\n"
"char \134\042 attrs string\n"
"char \042\134n\042 attrs\n"
"char \042&\042 .xml-entity:this\n"
"eat this\n"
"\n"
"state sq string\n"
"char \134' attrs string\n"
"char \042\134n\042 attrs\n"
"char \042&\042 .xml-entity:this\n"
"eat this\n"
"\n"
"default special entity\n"
"default text cdata\n"
"default constant cdata-delim\n"
;

static CONFIG_SECTION const char builtin_syntax_xresources[] =
"syntax xresources\n"
"\n"
"state start code\n"
"char \042 \134t\042 this\n"
"char ! comment\n"
"noeat line\n"
"\n"
"state line code\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
;

static CONFIG_SECTION const char builtin_syntax_zig[] =
"syntax .zig-esc\n"
"\n"
"state esc special\n"
"char \042nrt'\134\134\134\042\042 END special\n"
"noeat END\n"
"\n"
"syntax .zig-string\n"
"\n"
"state string\n"
"char '\042' END string\n"
"char \042\134n\042 END error\n"
"char \042\134\134\042 .zig-esc:this\n"
"eat this\n"
"\n"
"syntax zig\n"
"\n"
"state start code\n"
"char -b iu maybe-int-type\n"
"char -b a-z_@ ident\n"
"char -b A-Z ident-upper\n"
"char \134\042 .zig-string:this\n"
"str '//' comment\n"
"eat this\n"
"\n"
"state ident\n"
"char -b a-zA-Z0-9_ this\n"
"inlist keyword start\n"
"inlist type start\n"
"inlist constant start\n"
"inlist builtin start\n"
"noeat start\n"
"\n"
"state ident-upper ident\n"
"char -b a-z class-name-start\n"
"char -b A-Z0-9_ ident\n"
"noeat start\n"
"\n"
"state class-name-start\n"
"recolor class-name\n"
"noeat class-name\n"
"\n"
"state class-name\n"
"char a-zA-Z0-9_ this\n"
"noeat start\n"
"\n"
"state maybe-int-type type\n"
"char 1-9 int-type\n"
"recolor ident 1\n"
"noeat -b ident\n"
"\n"
"state int-type type\n"
"char 0-9 this\n"
"noeat start\n"
"\n"
"state comment\n"
"char \042\134n\042 start\n"
"eat this\n"
"\n"
"list keyword \134\n"
"align allowzero and anyframe anytype asm async await break \134\n"
"catch comptime const continue defer else enum errdefer error \134\n"
"export extern fn for if inline linksection noalias nosuspend \134\n"
"or orelse packed pub resume return struct suspend switch test \134\n"
"threadlocal try union unreachable usingnamespace \134\n"
"var volatile while\n"
"\n"
"list type \134\n"
"bool f16 f32 f64 f128 void noreturn type anyerror promise \134\n"
"i0 u0 isize usize comptime_int comptime_float \134\n"
"c_short c_ushort c_int c_uint c_long c_ulong c_longlong \134\n"
"c_ulonglong c_longdouble c_void\n"
"\n"
"list constant \134\n"
"null undefined true false\n"
"\n"
"list builtin \134\n"
"@Frame @TagType @This @Type @TypeOf @Vector \134\n"
"@addWithOverflow @alignCast @alignOf @as @asyncCall \134\n"
"@atomicLoad @atomicRmw @atomicStore \134\n"
"@bitCast @bitOffsetOf @bitReverse @boolToInt @breakpoint \134\n"
"@byteOffsetOf @byteSwap @bytesToSlice @cDefine @cImport \134\n"
"@cInclude @cUndef @call @ceil @clz @cmpxchgStrong @cmpxchgWeak \134\n"
"@compileError @compileLog @cos @ctz @divExact @divFloor \134\n"
"@divTrunc @embedFile @enumToInt @errSetCast @errorName \134\n"
"@errorReturnTrace @errorToInt @exp @exp2 @export @fabs \134\n"
"@fence @field @fieldParentPtr @floatCast @floatToInt @floor \134\n"
"@frame @frameAddress @hasDecl @hasField @import @intCast \134\n"
"@intToEnum @intToError @intToFloat @intToPtr @log @log2 @log10 \134\n"
"@memcpy @memset @mod @mulAdd @mulWithOverflow @panic \134\n"
"@popCount @ptrCast @ptrToInt @reduce @rem @returnAddress @round \134\n"
"@setAlignStack @setCold @setEvalBranchQuota @setFloatMode \134\n"
"@setRuntimeSafety @shlExact @shlWithOverflow @shrExact \134\n"
"@shuffle @splat @sin @src @sizeOf @sliceToBytes @sqrt \134\n"
"@subWithOverflow @tagName @trunc @truncate \134\n"
"@typeInfo @typeName @unionInit @wasmMemorySize @wasmMemoryGrow\n"
;

static CONFIG_SECTION const char builtin_syntax_inc_c_comment[] =
"syntax .c-comment\n"
"\n"
"state comment\n"
"char '*' star\n"
"eat this\n"
"\n"
"state star comment\n"
"char / END comment\n"
"noeat comment\n"
;

static CONFIG_SECTION const char builtin_syntax_inc_c_uchar[] =
"syntax .c-uchar4\n"
"\n"
"state 4left\n"
"char 0-9a-fA-F 3left special\n"
"eat END error\n"
"\n"
"state 3left\n"
"char 0-9a-fA-F 2left special\n"
"eat END error\n"
"\n"
"state 2left\n"
"char 0-9a-fA-F 1left special\n"
"eat END error\n"
"\n"
"state 1left\n"
"char 0-9a-fA-F END special\n"
"eat END error\n"
"\n"
"syntax .c-uchar8\n"
"\n"
"state 8left\n"
"char 0-9a-fA-F 7left special\n"
"eat END error\n"
"\n"
"state 7left\n"
"char 0-9a-fA-F 6left special\n"
"eat END error\n"
"\n"
"state 6left\n"
"char 0-9a-fA-F 5left special\n"
"eat END error\n"
"\n"
"state 5left\n"
"char 0-9a-fA-F .c-uchar4:END special\n"
"eat END error\n"
;

UNIGNORE_WARNINGS

#define cfg(n, t) { \
    .name = n, \
    .text = {.data = t, .length = sizeof(t) - 1} \
}

static CONFIG_SECTION const BuiltinConfig builtin_configs[] = {
    cfg("rc", builtin_rc),
    cfg("binding/default", builtin_binding_default),
    cfg("compiler/gcc", builtin_compiler_gcc),
    cfg("compiler/go", builtin_compiler_go),
    cfg("color/reset", builtin_color_reset),
    cfg("color/default", builtin_color_default),
    cfg("color/darkgray", builtin_color_darkgray),
    cfg("syntax/awk", builtin_syntax_awk),
    cfg("syntax/c", builtin_syntax_c),
    cfg("syntax/coccinelle", builtin_syntax_coccinelle),
    cfg("syntax/config", builtin_syntax_config),
    cfg("syntax/css", builtin_syntax_css),
    cfg("syntax/d", builtin_syntax_d),
    cfg("syntax/diff", builtin_syntax_diff),
    cfg("syntax/docker", builtin_syntax_docker),
    cfg("syntax/dte", builtin_syntax_dte),
    cfg("syntax/gcode", builtin_syntax_gcode),
    cfg("syntax/gitcommit", builtin_syntax_gitcommit),
    cfg("syntax/gitignore", builtin_syntax_gitignore),
    cfg("syntax/gitrebase", builtin_syntax_gitrebase),
    cfg("syntax/go", builtin_syntax_go),
    cfg("syntax/gomod", builtin_syntax_gomod),
    cfg("syntax/html", builtin_syntax_html),
    cfg("syntax/ini", builtin_syntax_ini),
    cfg("syntax/java", builtin_syntax_java),
    cfg("syntax/javascript", builtin_syntax_javascript),
    cfg("syntax/json", builtin_syntax_json),
    cfg("syntax/lisp", builtin_syntax_lisp),
    cfg("syntax/lua", builtin_syntax_lua),
    cfg("syntax/mail", builtin_syntax_mail),
    cfg("syntax/make", builtin_syntax_make),
    cfg("syntax/markdown", builtin_syntax_markdown),
    cfg("syntax/meson", builtin_syntax_meson),
    cfg("syntax/nginx", builtin_syntax_nginx),
    cfg("syntax/ninja", builtin_syntax_ninja),
    cfg("syntax/php", builtin_syntax_php),
    cfg("syntax/python", builtin_syntax_python),
    cfg("syntax/robotstxt", builtin_syntax_robotstxt),
    cfg("syntax/roff", builtin_syntax_roff),
    cfg("syntax/ruby", builtin_syntax_ruby),
    cfg("syntax/scheme", builtin_syntax_scheme),
    cfg("syntax/sed", builtin_syntax_sed),
    cfg("syntax/sh", builtin_syntax_sh),
    cfg("syntax/sql", builtin_syntax_sql),
    cfg("syntax/tex", builtin_syntax_tex),
    cfg("syntax/texmfcnf", builtin_syntax_texmfcnf),
    cfg("syntax/tmux", builtin_syntax_tmux),
    cfg("syntax/vala", builtin_syntax_vala),
    cfg("syntax/xml", builtin_syntax_xml),
    cfg("syntax/xresources", builtin_syntax_xresources),
    cfg("syntax/zig", builtin_syntax_zig),
    cfg("syntax/inc/c-comment", builtin_syntax_inc_c_comment),
    cfg("syntax/inc/c-uchar", builtin_syntax_inc_c_uchar),
};
